
package de.tudresden.ws;

import java.util.List;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.ws.Action;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;


/**
 * This class was generated by the JAX-WS RI.
 * JAX-WS RI 2.2.4-b01
 * Generated source version: 2.2
 * 
 */
@WebService(name = "Service_Impl", targetNamespace = "http://ws.tudresden.de/")
@XmlSeeAlso({
    ObjectFactory.class
})
public interface ServiceImpl {


    /**
     * 
     * @param user
     * @return
     *     returns java.lang.String
     */
    @WebMethod(action = "start service")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "start", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.Start")
    @ResponseWrapper(localName = "startResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.StartResponse")
    @Action(input = "start service", output = "http://ws.tudresden.de/Service_Impl/startResponse")
    public String start(
        @WebParam(name = "user", targetNamespace = "")
        String user);

    /**
     * 
     * @param user
     * @return
     *     returns java.lang.String
     */
    @WebMethod(action = "stop service")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "stop", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.Stop")
    @ResponseWrapper(localName = "stopResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.StopResponse")
    @Action(input = "stop service", output = "http://ws.tudresden.de/Service_Impl/stopResponse")
    public String stop(
        @WebParam(name = "user", targetNamespace = "")
        String user);

    /**
     * 
     * @param binary
     */
    @WebMethod(action = "set the sumo binary")
    @RequestWrapper(localName = "setSumoBinary", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SetSumoBinary")
    @ResponseWrapper(localName = "setSumoBinaryResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SetSumoBinaryResponse")
    @Action(input = "set the sumo binary", output = "http://ws.tudresden.de/Service_Impl/setSumoBinaryResponse")
    public void setSumoBinary(
        @WebParam(name = "binary", targetNamespace = "")
        String binary);

    /**
     * 
     * @param filename
     */
    @WebMethod(action = "set the configuration file")
    @RequestWrapper(localName = "setConfig", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SetConfig")
    @ResponseWrapper(localName = "setConfigResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SetConfigResponse")
    @Action(input = "set the configuration file", output = "http://ws.tudresden.de/Service_Impl/setConfigResponse")
    public void setConfig(
        @WebParam(name = "filename", targetNamespace = "")
        String filename);

    /**
     * 
     * @param arg1
     * @param arg0
     */
    @WebMethod(action = "add Options to sumo binary")
    @RequestWrapper(localName = "addOption", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.AddOption")
    @ResponseWrapper(localName = "addOptionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.AddOptionResponse")
    @Action(input = "add Options to sumo binary", output = "http://ws.tudresden.de/Service_Impl/addOptionResponse")
    public void addOption(
        @WebParam(name = "arg0", targetNamespace = "")
        String arg0,
        @WebParam(name = "arg1", targetNamespace = "")
        String arg1);

    /**
     * 
     */
    @WebMethod(action = "do timestep")
    @RequestWrapper(localName = "doTimestep", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.DoTimestep")
    @ResponseWrapper(localName = "doTimestepResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.DoTimestepResponse")
    @Action(input = "do timestep", output = "http://ws.tudresden.de/Service_Impl/doTimestepResponse")
    public void doTimestep();

    /**
     * 
     * @return
     *     returns java.lang.String
     */
    @WebMethod(action = "version info")
    @WebResult(name = "output", targetNamespace = "")
    @RequestWrapper(localName = "version", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.Version")
    @ResponseWrapper(localName = "versionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VersionResponse")
    @Action(input = "version info", output = "http://ws.tudresden.de/Service_Impl/versionResponse")
    public String version();

    /**
     * 
     * @param user
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "get_Status", action = "status")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "get_Status", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GetStatus")
    @ResponseWrapper(localName = "get_StatusResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GetStatusResponse")
    @Action(input = "status", output = "http://ws.tudresden.de/Service_Impl/get_StatusResponse")
    public String getStatus(
        @WebParam(name = "user", targetNamespace = "")
        String user);

    /**
     * 
     * @param active
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "TXT_output", action = "activate text output. only for debugging purposes.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "TXT_output", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TXTOutput")
    @ResponseWrapper(localName = "TXT_outputResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TXTOutputResponse")
    @Action(input = "activate text output. only for debugging purposes.", output = "http://ws.tudresden.de/Service_Impl/TXT_outputResponse")
    public String txtOutput(
        @WebParam(name = "active", targetNamespace = "")
        boolean active);

    /**
     * 
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "LastActionTime", action = "last action time")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "LastActionTime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LastActionTime")
    @ResponseWrapper(localName = "LastActionTimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LastActionTimeResponse")
    @Action(input = "last action time", output = "http://ws.tudresden.de/Service_Impl/LastActionTimeResponse")
    public String lastActionTime();

    /**
     * 
     * @param tlsID
     * @param tls
     */
    @WebMethod(operationName = "Trafficlights_setCompleteRedYellowGreenDefinition", action = "Trafficlights: setCompleteRedYellowGreenDefinition")
    @RequestWrapper(localName = "Trafficlights_setCompleteRedYellowGreenDefinition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetCompleteRedYellowGreenDefinition")
    @ResponseWrapper(localName = "Trafficlights_setCompleteRedYellowGreenDefinitionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetCompleteRedYellowGreenDefinitionResponse")
    @Action(input = "Trafficlights: setCompleteRedYellowGreenDefinition", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_setCompleteRedYellowGreenDefinitionResponse")
    public void trafficlightsSetCompleteRedYellowGreenDefinition(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID,
        @WebParam(name = "tls", targetNamespace = "")
        SumoTLSLogic tls);

    /**
     * 
     * @param tlsID
     * @return
     *     returns de.tudresden.ws.SumoTLSLogic
     */
    @WebMethod(operationName = "Trafficlights_getCompleteRedYellowGreenDefinition", action = "Trafficlights: getCompleteRedYellowGreenDefinition")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getCompleteRedYellowGreenDefinition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetCompleteRedYellowGreenDefinition")
    @ResponseWrapper(localName = "Trafficlights_getCompleteRedYellowGreenDefinitionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetCompleteRedYellowGreenDefinitionResponse")
    @Action(input = "Trafficlights: getCompleteRedYellowGreenDefinition", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getCompleteRedYellowGreenDefinitionResponse")
    public SumoTLSLogic trafficlightsGetCompleteRedYellowGreenDefinition(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param time
     * @param edgeID
     */
    @WebMethod(operationName = "Edge_adaptTraveltime", action = "Edge: adapt the Traveltime")
    @RequestWrapper(localName = "Edge_adaptTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeAdaptTraveltime")
    @ResponseWrapper(localName = "Edge_adaptTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeAdaptTraveltimeResponse")
    @Action(input = "Edge: adapt the Traveltime", output = "http://ws.tudresden.de/Service_Impl/Edge_adaptTraveltimeResponse")
    public void edgeAdaptTraveltime(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "time", targetNamespace = "")
        int time);

    /**
     * 
     * @param edgeID
     * @param effort
     */
    @WebMethod(operationName = "Edge_setEffort", action = "Edge: setEffort")
    @RequestWrapper(localName = "Edge_setEffort", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeSetEffort")
    @ResponseWrapper(localName = "Edge_setEffortResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeSetEffortResponse")
    @Action(input = "Edge: setEffort", output = "http://ws.tudresden.de/Service_Impl/Edge_setEffortResponse")
    public void edgeSetEffort(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "effort", targetNamespace = "")
        double effort);

    /**
     * 
     * @param speed
     * @param edgeID
     */
    @WebMethod(operationName = "Edge_setMaxSpeed", action = "Edge: Set a new maximum speed (in m/s) for all lanes of the edge..")
    @RequestWrapper(localName = "Edge_setMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeSetMaxSpeed")
    @ResponseWrapper(localName = "Edge_setMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeSetMaxSpeedResponse")
    @Action(input = "Edge: Set a new maximum speed (in m/s) for all lanes of the edge..", output = "http://ws.tudresden.de/Service_Impl/Edge_setMaxSpeedResponse")
    public void edgeSetMaxSpeed(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed);

    /**
     * 
     * @param duration
     * @param laneIndex
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_changeLane", action = "Vehicle: changeLane")
    @RequestWrapper(localName = "Vehicle_changeLane", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleChangeLane")
    @ResponseWrapper(localName = "Vehicle_changeLaneResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleChangeLaneResponse")
    @Action(input = "Vehicle: changeLane", output = "http://ws.tudresden.de/Service_Impl/Vehicle_changeLaneResponse")
    public void vehicleChangeLane(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "laneIndex", targetNamespace = "")
        byte laneIndex,
        @WebParam(name = "duration", targetNamespace = "")
        int duration);

    /**
     * 
     * @param speed
     * @param depart
     * @param routeID
     * @param vehID
     * @param lane
     * @param pos
     * @param typeID
     */
    @WebMethod(operationName = "Vehicle_add", action = "Vehicle: add")
    @RequestWrapper(localName = "Vehicle_add", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleAdd")
    @ResponseWrapper(localName = "Vehicle_addResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleAddResponse")
    @Action(input = "Vehicle: add", output = "http://ws.tudresden.de/Service_Impl/Vehicle_addResponse")
    public void vehicleAdd(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "routeID", targetNamespace = "")
        String routeID,
        @WebParam(name = "depart", targetNamespace = "")
        int depart,
        @WebParam(name = "pos", targetNamespace = "")
        double pos,
        @WebParam(name = "speed", targetNamespace = "")
        double speed,
        @WebParam(name = "lane", targetNamespace = "")
        byte lane);

    /**
     * 
     * @param color
     * @param fill
     * @param layer
     * @param shape
     * @param polygonID
     * @param polygonType
     */
    @WebMethod(operationName = "Polygon_add", action = "Polygon: add")
    @RequestWrapper(localName = "Polygon_add", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonAdd")
    @ResponseWrapper(localName = "Polygon_addResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonAddResponse")
    @Action(input = "Polygon: add", output = "http://ws.tudresden.de/Service_Impl/Polygon_addResponse")
    public void polygonAdd(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID,
        @WebParam(name = "shape", targetNamespace = "")
        SumoGeometry shape,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color,
        @WebParam(name = "fill", targetNamespace = "")
        boolean fill,
        @WebParam(name = "polygonType", targetNamespace = "")
        String polygonType,
        @WebParam(name = "layer", targetNamespace = "")
        int layer);

    /**
     * 
     * @param layer
     * @param poiID
     */
    @WebMethod(operationName = "Poi_remove", action = "Poi: remove")
    @RequestWrapper(localName = "Poi_remove", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiRemove")
    @ResponseWrapper(localName = "Poi_removeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiRemoveResponse")
    @Action(input = "Poi: remove", output = "http://ws.tudresden.de/Service_Impl/Poi_removeResponse")
    public void poiRemove(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID,
        @WebParam(name = "layer", targetNamespace = "")
        int layer);

    /**
     * 
     * @param color
     * @param poiID
     */
    @WebMethod(operationName = "Poi_setColor", action = "Poi: setColor")
    @RequestWrapper(localName = "Poi_setColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetColor")
    @ResponseWrapper(localName = "Poi_setColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetColorResponse")
    @Action(input = "Poi: setColor", output = "http://ws.tudresden.de/Service_Impl/Poi_setColorResponse")
    public void poiSetColor(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color);

    /**
     * 
     * @param poiType
     * @param poiID
     */
    @WebMethod(operationName = "Poi_setType", action = "Poi: setType")
    @RequestWrapper(localName = "Poi_setType", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetType")
    @ResponseWrapper(localName = "Poi_setTypeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetTypeResponse")
    @Action(input = "Poi: setType", output = "http://ws.tudresden.de/Service_Impl/Poi_setTypeResponse")
    public void poiSetType(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID,
        @WebParam(name = "poiType", targetNamespace = "")
        String poiType);

    /**
     * 
     * @param viewID
     * @param y
     * @param x
     */
    @WebMethod(operationName = "GUI_setOffset", action = "Gui: Set the current offset for the given view.")
    @RequestWrapper(localName = "GUI_setOffset", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetOffset")
    @ResponseWrapper(localName = "GUI_setOffsetResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetOffsetResponse")
    @Action(input = "Gui: Set the current offset for the given view.", output = "http://ws.tudresden.de/Service_Impl/GUI_setOffsetResponse")
    public void guiSetOffset(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y);

    /**
     * 
     * @param schemeName
     * @param viewID
     */
    @WebMethod(operationName = "GUI_setSchema", action = "Gui: Set the current coloring scheme for the given view.")
    @RequestWrapper(localName = "GUI_setSchema", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetSchema")
    @ResponseWrapper(localName = "GUI_setSchemaResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetSchemaResponse")
    @Action(input = "Gui: Set the current coloring scheme for the given view.", output = "http://ws.tudresden.de/Service_Impl/GUI_setSchemaResponse")
    public void guiSetSchema(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "schemeName", targetNamespace = "")
        String schemeName);

    /**
     * 
     * @param zoom
     * @param viewID
     */
    @WebMethod(operationName = "GUI_setZoom", action = "Gui: Set the current zoom factor for the given view.")
    @RequestWrapper(localName = "GUI_setZoom", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetZoom")
    @ResponseWrapper(localName = "GUI_setZoomResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetZoomResponse")
    @Action(input = "Gui: Set the current zoom factor for the given view.", output = "http://ws.tudresden.de/Service_Impl/GUI_setZoomResponse")
    public void guiSetZoom(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "zoom", targetNamespace = "")
        double zoom);

    /**
     * 
     * @param edges
     * @param routeID
     */
    @WebMethod(operationName = "Route_add", action = "Route: add")
    @RequestWrapper(localName = "Route_add", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteAdd")
    @ResponseWrapper(localName = "Route_addResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteAddResponse")
    @Action(input = "Route: add", output = "http://ws.tudresden.de/Service_Impl/Route_addResponse")
    public void routeAdd(
        @WebParam(name = "routeID", targetNamespace = "")
        String routeID,
        @WebParam(name = "edges", targetNamespace = "")
        List<String> edges);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getStartingTeleportIDList", action = "Simulation: getStartingTeleportIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStartingTeleportIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStartingTeleportIDList")
    @ResponseWrapper(localName = "Simulation_getStartingTeleportIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStartingTeleportIDListResponse")
    @Action(input = "Simulation: getStartingTeleportIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStartingTeleportIDListResponse")
    public List<String> simulationGetStartingTeleportIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getStartingTeleportNumber", action = "Simulation: getStartingTeleportNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStartingTeleportNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStartingTeleportNumber")
    @ResponseWrapper(localName = "Simulation_getStartingTeleportNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStartingTeleportNumberResponse")
    @Action(input = "Simulation: getStartingTeleportNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStartingTeleportNumberResponse")
    public int simulationGetStartingTeleportNumber();

    /**
     * 
     * @param tlsID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Trafficlights_getControlledLanes", action = "Trafficlights: getControlledLanes")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getControlledLanes", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetControlledLanes")
    @ResponseWrapper(localName = "Trafficlights_getControlledLanesResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetControlledLanesResponse")
    @Action(input = "Trafficlights: getControlledLanes", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getControlledLanesResponse")
    public List<String> trafficlightsGetControlledLanes(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param tlsID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Trafficlights_getControlledLinks", action = "Trafficlights: getControlledLinks")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getControlledLinks", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetControlledLinks")
    @ResponseWrapper(localName = "Trafficlights_getControlledLinksResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetControlledLinksResponse")
    @Action(input = "Trafficlights: getControlledLinks", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getControlledLinksResponse")
    public List<String> trafficlightsGetControlledLinks(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param tlsID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Trafficlights_getPhaseDuration", action = "Trafficlights: Returns the phase duration")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getPhaseDuration", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetPhaseDuration")
    @ResponseWrapper(localName = "Trafficlights_getPhaseDurationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetPhaseDurationResponse")
    @Action(input = "Trafficlights: Returns the phase duration", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getPhaseDurationResponse")
    public int trafficlightsGetPhaseDuration(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param tlsID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Trafficlights_getRedYellowGreenState", action = "Trafficlights: getRedYellowGreenState")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getRedYellowGreenState", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetRedYellowGreenState")
    @ResponseWrapper(localName = "Trafficlights_getRedYellowGreenStateResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetRedYellowGreenStateResponse")
    @Action(input = "Trafficlights: getRedYellowGreenState", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getRedYellowGreenStateResponse")
    public String trafficlightsGetRedYellowGreenState(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Inductionloop_getLastStepMeanLength", action = "Inductionloop: getLastStepMeanLength")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLastStepMeanLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepMeanLength")
    @ResponseWrapper(localName = "Inductionloop_getLastStepMeanLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepMeanLengthResponse")
    @Action(input = "Inductionloop: getLastStepMeanLength", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLastStepMeanLengthResponse")
    public double inductionloopGetLastStepMeanLength(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Inductionloop_getLastStepMeanSpeed", action = "Inductionloop: getLastStepMeanSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLastStepMeanSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepMeanSpeed")
    @ResponseWrapper(localName = "Inductionloop_getLastStepMeanSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepMeanSpeedResponse")
    @Action(input = "Inductionloop: getLastStepMeanSpeed", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLastStepMeanSpeedResponse")
    public double inductionloopGetLastStepMeanSpeed(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Inductionloop_getLastStepOccupancy", action = "Inductionloop: getLastStepOccupancy")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLastStepOccupancy", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepOccupancy")
    @ResponseWrapper(localName = "Inductionloop_getLastStepOccupancyResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepOccupancyResponse")
    @Action(input = "Inductionloop: getLastStepOccupancy", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLastStepOccupancyResponse")
    public double inductionloopGetLastStepOccupancy(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Inductionloop_getLastStepVehicleIDs", action = "Inductionloop: getLastStepVehicleIDs")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLastStepVehicleIDs", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepVehicleIDs")
    @ResponseWrapper(localName = "Inductionloop_getLastStepVehicleIDsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepVehicleIDsResponse")
    @Action(input = "Inductionloop: getLastStepVehicleIDs", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLastStepVehicleIDsResponse")
    public List<String> inductionloopGetLastStepVehicleIDs(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Inductionloop_getLastStepVehicleNumber", action = "Inductionloop: getLastStepVehicleNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLastStepVehicleNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepVehicleNumber")
    @ResponseWrapper(localName = "Inductionloop_getLastStepVehicleNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLastStepVehicleNumberResponse")
    @Action(input = "Inductionloop: getLastStepVehicleNumber", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLastStepVehicleNumberResponse")
    public int inductionloopGetLastStepVehicleNumber(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Inductionloop_getTimeSinceDetection", action = "Inductionloop: getTimeSinceDetection")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getTimeSinceDetection", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetTimeSinceDetection")
    @ResponseWrapper(localName = "Inductionloop_getTimeSinceDetectionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetTimeSinceDetectionResponse")
    @Action(input = "Inductionloop: getTimeSinceDetection", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getTimeSinceDetectionResponse")
    public double inductionloopGetTimeSinceDetection(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param laneID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Lane_getAllowed", action = "Lane: getAllowed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getAllowed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetAllowed")
    @ResponseWrapper(localName = "Lane_getAllowedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetAllowedResponse")
    @Action(input = "Lane: getAllowed", output = "http://ws.tudresden.de/Service_Impl/Lane_getAllowedResponse")
    public List<String> laneGetAllowed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getCO2Emission", action = "Lane: Returns the CO2 emission in mg for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getCO2Emission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetCO2Emission")
    @ResponseWrapper(localName = "Lane_getCO2EmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetCO2EmissionResponse")
    @Action(input = "Lane: Returns the CO2 emission in mg for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getCO2EmissionResponse")
    public double laneGetCO2Emission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getCOEmission", action = "Lane: Returns the CO emission in mg for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getCOEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetCOEmission")
    @ResponseWrapper(localName = "Lane_getCOEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetCOEmissionResponse")
    @Action(input = "Lane: Returns the CO emission in mg for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getCOEmissionResponse")
    public double laneGetCOEmission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Lane_getDisallowed", action = "Lane: getDisallowed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getDisallowed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetDisallowed")
    @ResponseWrapper(localName = "Lane_getDisallowedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetDisallowedResponse")
    @Action(input = "Lane: getDisallowed", output = "http://ws.tudresden.de/Service_Impl/Lane_getDisallowedResponse")
    public List<String> laneGetDisallowed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Lane_getEdgeID", action = "Lane: getEdgeID")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getEdgeID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetEdgeID")
    @ResponseWrapper(localName = "Lane_getEdgeIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetEdgeIDResponse")
    @Action(input = "Lane: getEdgeID", output = "http://ws.tudresden.de/Service_Impl/Lane_getEdgeIDResponse")
    public String laneGetEdgeID(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getFuelConsumption", action = "Lane: Returns the fuel consumption in ml for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getFuelConsumption", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetFuelConsumption")
    @ResponseWrapper(localName = "Lane_getFuelConsumptionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetFuelConsumptionResponse")
    @Action(input = "Lane: Returns the fuel consumption in ml for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getFuelConsumptionResponse")
    public double laneGetFuelConsumption(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getHCEmission", action = "Lane: Returns the HC emission in mg for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getHCEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetHCEmission")
    @ResponseWrapper(localName = "Lane_getHCEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetHCEmissionResponse")
    @Action(input = "Lane: Returns the HC emission in mg for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getHCEmissionResponse")
    public double laneGetHCEmission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Lane_getIDList", action = "Lane: Returns a list of all lanes in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetIDList")
    @ResponseWrapper(localName = "Lane_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetIDListResponse")
    @Action(input = "Lane: Returns a list of all lanes in the network.", output = "http://ws.tudresden.de/Service_Impl/Lane_getIDListResponse")
    public List<String> laneGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Lane_getIDCount", action = "Lane: Returns the number of all lanes in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetIDCount")
    @ResponseWrapper(localName = "Lane_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetIDCountResponse")
    @Action(input = "Lane: Returns the number of all lanes in the network.", output = "http://ws.tudresden.de/Service_Impl/Lane_getIDCountResponse")
    public int laneGetIDCount();

    /**
     * 
     * @param laneID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Lane_getLastStepHaltingNumber", action = "Lane: Returns the total number of halting vehicles for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepHaltingNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepHaltingNumber")
    @ResponseWrapper(localName = "Lane_getLastStepHaltingNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepHaltingNumberResponse")
    @Action(input = "Lane: Returns the total number of halting vehicles for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepHaltingNumberResponse")
    public int laneGetLastStepHaltingNumber(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getLastStepLength", action = "Lane: Returns the total vehicle length in m for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepLength")
    @ResponseWrapper(localName = "Lane_getLastStepLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepLengthResponse")
    @Action(input = "Lane: Returns the total vehicle length in m for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepLengthResponse")
    public double laneGetLastStepLength(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getLastStepMeanSpeed", action = "Lane: Returns the average speed in m/s for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepMeanSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepMeanSpeed")
    @ResponseWrapper(localName = "Lane_getLastStepMeanSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepMeanSpeedResponse")
    @Action(input = "Lane: Returns the average speed in m/s for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepMeanSpeedResponse")
    public double laneGetLastStepMeanSpeed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getLastStepOccupancy", action = "Lane: Returns the occupancy in % for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepOccupancy", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepOccupancy")
    @ResponseWrapper(localName = "Lane_getLastStepOccupancyResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepOccupancyResponse")
    @Action(input = "Lane: Returns the occupancy in % for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepOccupancyResponse")
    public double laneGetLastStepOccupancy(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Lane_getLastStepVehicleIDs", action = "Lane: Returns the subscription results for the last time step and the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepVehicleIDs", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepVehicleIDs")
    @ResponseWrapper(localName = "Lane_getLastStepVehicleIDsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepVehicleIDsResponse")
    @Action(input = "Lane: Returns the subscription results for the last time step and the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepVehicleIDsResponse")
    public List<String> laneGetLastStepVehicleIDs(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Lane_getLastStepVehicleNumber", action = "Lane: Returns the total number of vehicles for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLastStepVehicleNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepVehicleNumber")
    @ResponseWrapper(localName = "Lane_getLastStepVehicleNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLastStepVehicleNumberResponse")
    @Action(input = "Lane: Returns the total number of vehicles for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getLastStepVehicleNumberResponse")
    public int laneGetLastStepVehicleNumber(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getLength", action = "Lane: getLength")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLength")
    @ResponseWrapper(localName = "Lane_getLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLengthResponse")
    @Action(input = "Lane: getLength", output = "http://ws.tudresden.de/Service_Impl/Lane_getLengthResponse")
    public double laneGetLength(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Lane_getLinkNumber", action = "Lane: getLinkNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLinkNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLinkNumber")
    @ResponseWrapper(localName = "Lane_getLinkNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLinkNumberResponse")
    @Action(input = "Lane: getLinkNumber", output = "http://ws.tudresden.de/Service_Impl/Lane_getLinkNumberResponse")
    public int laneGetLinkNumber(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getMaxSpeed", action = "Lane: getMaxSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetMaxSpeed")
    @ResponseWrapper(localName = "Lane_getMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetMaxSpeedResponse")
    @Action(input = "Lane: getMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Lane_getMaxSpeedResponse")
    public double laneGetMaxSpeed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getWaitingTime", action = "Lane: getWaitingTime")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getWaitingTime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetWaitingTime")
    @ResponseWrapper(localName = "Lane_getWaitingTimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetWaitingTimeResponse")
    @Action(input = "Lane: getWaitingTime", output = "http://ws.tudresden.de/Service_Impl/Lane_getWaitingTimeResponse")
    public double laneGetWaitingTime(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getNOxEmission", action = "Lane: Returns the NOx emission in mg for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getNOxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetNOxEmission")
    @ResponseWrapper(localName = "Lane_getNOxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetNOxEmissionResponse")
    @Action(input = "Lane: Returns the NOx emission in mg for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getNOxEmissionResponse")
    public double laneGetNOxEmission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getNoiseEmission", action = "Lane: Returns the noise emission in db for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getNoiseEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetNoiseEmission")
    @ResponseWrapper(localName = "Lane_getNoiseEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetNoiseEmissionResponse")
    @Action(input = "Lane: Returns the noise emission in db for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getNoiseEmissionResponse")
    public double laneGetNoiseEmission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getPMxEmission", action = "Lane: Returns the particular matter emission in mg for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getPMxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetPMxEmission")
    @ResponseWrapper(localName = "Lane_getPMxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetPMxEmissionResponse")
    @Action(input = "Lane: Returns the particular matter emission in mg for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getPMxEmissionResponse")
    public double laneGetPMxEmission(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getTraveltime", action = "Lane: Returns the estimated travel time in s for the last time step on the given lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetTraveltime")
    @ResponseWrapper(localName = "Lane_getTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetTraveltimeResponse")
    @Action(input = "Lane: Returns the estimated travel time in s for the last time step on the given lane.", output = "http://ws.tudresden.de/Service_Impl/Lane_getTraveltimeResponse")
    public double laneGetTraveltime(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param polygonID
     * @return
     *     returns de.tudresden.ws.SumoColor
     */
    @WebMethod(operationName = "Polygon_getColor", action = "Polygon: Returns the subscription results for the last time step and the given poi.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Polygon_getColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetColor")
    @ResponseWrapper(localName = "Polygon_getColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetColorResponse")
    @Action(input = "Polygon: Returns the subscription results for the last time step and the given poi.", output = "http://ws.tudresden.de/Service_Impl/Polygon_getColorResponse")
    public SumoColor polygonGetColor(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Polygon_getIDList", action = "Polygon: Returns a list of all polygons in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Polygon_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetIDList")
    @ResponseWrapper(localName = "Polygon_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetIDListResponse")
    @Action(input = "Polygon: Returns a list of all polygons in the network.", output = "http://ws.tudresden.de/Service_Impl/Polygon_getIDListResponse")
    public List<String> polygonGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Polygon_getIDCount", action = "Polygon: Returns the number of all polygons in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Polygon_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetIDCount")
    @ResponseWrapper(localName = "Polygon_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetIDCountResponse")
    @Action(input = "Polygon: Returns the number of all polygons in the network.", output = "http://ws.tudresden.de/Service_Impl/Polygon_getIDCountResponse")
    public int polygonGetIDCount();

    /**
     * 
     * @param polygonID
     * @return
     *     returns de.tudresden.ws.SumoGeometry
     */
    @WebMethod(operationName = "Polygon_getShape", action = "Polygon: getShape")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Polygon_getShape", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetShape")
    @ResponseWrapper(localName = "Polygon_getShapeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetShapeResponse")
    @Action(input = "Polygon: getShape", output = "http://ws.tudresden.de/Service_Impl/Polygon_getShapeResponse")
    public SumoGeometry polygonGetShape(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID);

    /**
     * 
     * @param polygonID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Polygon_getType", action = "Polygon: getType")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Polygon_getType", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetType")
    @ResponseWrapper(localName = "Polygon_getTypeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonGetTypeResponse")
    @Action(input = "Polygon: getType", output = "http://ws.tudresden.de/Service_Impl/Polygon_getTypeResponse")
    public String polygonGetType(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID);

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Poi_getIDCount", action = "Poi: Returns the number of all pois in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetIDCount")
    @ResponseWrapper(localName = "Poi_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetIDCountResponse")
    @Action(input = "Poi: Returns the number of all pois in the network.", output = "http://ws.tudresden.de/Service_Impl/Poi_getIDCountResponse")
    public int poiGetIDCount();

    /**
     * 
     * @param poiID
     * @return
     *     returns de.tudresden.ws.SumoPosition2D
     */
    @WebMethod(operationName = "Poi_getPosition", action = "Poi: getPosition")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_getPosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetPosition")
    @ResponseWrapper(localName = "Poi_getPositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetPositionResponse")
    @Action(input = "Poi: getPosition", output = "http://ws.tudresden.de/Service_Impl/Poi_getPositionResponse")
    public SumoPosition2D poiGetPosition(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Junction_getIDList", action = "Junction: Returns a list of all junctions in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Junction_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetIDList")
    @ResponseWrapper(localName = "Junction_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetIDListResponse")
    @Action(input = "Junction: Returns a list of all junctions in the network.", output = "http://ws.tudresden.de/Service_Impl/Junction_getIDListResponse")
    public List<String> junctionGetIDList();

    /**
     * 
     * @param junctionID
     * @return
     *     returns de.tudresden.ws.SumoGeometry
     */
    @WebMethod(operationName = "Junction_getShape", action = "Junction: getShape")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Junction_getShape", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetShape")
    @ResponseWrapper(localName = "Junction_getShapeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetShapeResponse")
    @Action(input = "Junction: getShape", output = "http://ws.tudresden.de/Service_Impl/Junction_getShapeResponse")
    public SumoGeometry junctionGetShape(
        @WebParam(name = "junctionID", targetNamespace = "")
        String junctionID);

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Junction_getIDCount", action = "Junction: Returns the number of all junctions in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Junction_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetIDCount")
    @ResponseWrapper(localName = "Junction_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetIDCountResponse")
    @Action(input = "Junction: Returns the number of all junctions in the network.", output = "http://ws.tudresden.de/Service_Impl/Junction_getIDCountResponse")
    public int junctionGetIDCount();

    /**
     * 
     * @param junctionID
     * @return
     *     returns de.tudresden.ws.SumoPosition2D
     */
    @WebMethod(operationName = "Junction_getPosition", action = "Junction: Returns the subscription results for the last time step and the given junction.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Junction_getPosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetPosition")
    @ResponseWrapper(localName = "Junction_getPositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.JunctionGetPositionResponse")
    @Action(input = "Junction: Returns the subscription results for the last time step and the given junction.", output = "http://ws.tudresden.de/Service_Impl/Junction_getPositionResponse")
    public SumoPosition2D junctionGetPosition(
        @WebParam(name = "junctionID", targetNamespace = "")
        String junctionID);

    /**
     * 
     * @param viewID
     * @return
     *     returns de.tudresden.ws.SumoBoundingBox
     */
    @WebMethod(operationName = "GUI_getBoundary", action = "Gui: Returns the subscription results for the last time step and the given view.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "GUI_getBoundary", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetBoundary")
    @ResponseWrapper(localName = "GUI_getBoundaryResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetBoundaryResponse")
    @Action(input = "Gui: Returns the subscription results for the last time step and the given view.", output = "http://ws.tudresden.de/Service_Impl/GUI_getBoundaryResponse")
    public SumoBoundingBox guiGetBoundary(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID);

    /**
     * 
     * @param routeID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Route_getEdges", action = "Route: Returns the subscription results for the last time step and the given route.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Route_getEdges", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetEdges")
    @ResponseWrapper(localName = "Route_getEdgesResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetEdgesResponse")
    @Action(input = "Route: Returns the subscription results for the last time step and the given route.", output = "http://ws.tudresden.de/Service_Impl/Route_getEdgesResponse")
    public List<String> routeGetEdges(
        @WebParam(name = "routeID", targetNamespace = "")
        String routeID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Route_getIDList", action = "Route: Returns a list of all routes in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Route_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetIDList")
    @ResponseWrapper(localName = "Route_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetIDListResponse")
    @Action(input = "Route: Returns a list of all routes in the network.", output = "http://ws.tudresden.de/Service_Impl/Route_getIDListResponse")
    public List<String> routeGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Route_getIDCount", action = "Route: Returns the number of all routes in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Route_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetIDCount")
    @ResponseWrapper(localName = "Route_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.RouteGetIDCountResponse")
    @Action(input = "Route: Returns the number of all routes in the network.", output = "http://ws.tudresden.de/Service_Impl/Route_getIDCountResponse")
    public int routeGetIDCount();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Inductionloop_getIDList", action = "Inductionloop: Returns a list of all induction loops in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetIDList")
    @ResponseWrapper(localName = "Inductionloop_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetIDListResponse")
    @Action(input = "Inductionloop: Returns a list of all induction loops in the network.", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getIDListResponse")
    public List<String> inductionloopGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Inductionloop_getIDCount", action = "Inductionloop: Returns the number of induction loops in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetIDCount")
    @ResponseWrapper(localName = "Inductionloop_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetIDCountResponse")
    @Action(input = "Inductionloop: Returns the number of induction loops in the network.", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getIDCountResponse")
    public int inductionloopGetIDCount();

    /**
     * 
     * @param loopID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Inductionloop_getLaneID", action = "Inductionloop: Returns the id of the lane the loop is on.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getLaneID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLaneID")
    @ResponseWrapper(localName = "Inductionloop_getLaneIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetLaneIDResponse")
    @Action(input = "Inductionloop: Returns the id of the lane the loop is on.", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getLaneIDResponse")
    public String inductionloopGetLaneID(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Inductionloop_getPosition", action = "Inductionloop: Returns the position measured from the beginning of the lane.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getPosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetPosition")
    @ResponseWrapper(localName = "Inductionloop_getPositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetPositionResponse")
    @Action(input = "Inductionloop: Returns the position measured from the beginning of the lane.", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getPositionResponse")
    public double inductionloopGetPosition(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Inductionloop_getVehicleData", action = "Inductionloop: Returns the subscription results for the last time step and the given loop.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Inductionloop_getVehicleData", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetVehicleData")
    @ResponseWrapper(localName = "Inductionloop_getVehicleDataResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.InductionloopGetVehicleDataResponse")
    @Action(input = "Inductionloop: Returns the subscription results for the last time step and the given loop.", output = "http://ws.tudresden.de/Service_Impl/Inductionloop_getVehicleDataResponse")
    public int inductionloopGetVehicleData(
        @WebParam(name = "loopID", targetNamespace = "")
        List<String> loopID);

    /**
     * 
     * @param tlsID
     * @param phaseDuration
     */
    @WebMethod(operationName = "Trafficlights_setPhaseDuration", action = "Trafficlights: setPhaseDuration")
    @RequestWrapper(localName = "Trafficlights_setPhaseDuration", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetPhaseDuration")
    @ResponseWrapper(localName = "Trafficlights_setPhaseDurationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetPhaseDurationResponse")
    @Action(input = "Trafficlights: setPhaseDuration", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_setPhaseDurationResponse")
    public void trafficlightsSetPhaseDuration(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID,
        @WebParam(name = "phaseDuration", targetNamespace = "")
        int phaseDuration);

    /**
     * 
     * @param tlsID
     * @param state
     */
    @WebMethod(operationName = "Trafficlights_setRedYellowGreenState", action = "Trafficlights: setRedYellowGreenState")
    @RequestWrapper(localName = "Trafficlights_setRedYellowGreenState", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetRedYellowGreenState")
    @ResponseWrapper(localName = "Trafficlights_setRedYellowGreenStateResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetRedYellowGreenStateResponse")
    @Action(input = "Trafficlights: setRedYellowGreenState", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_setRedYellowGreenStateResponse")
    public void trafficlightsSetRedYellowGreenState(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID,
        @WebParam(name = "state", targetNamespace = "")
        String state);

    /**
     * 
     * @param detID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Multientryexit_getLastStepHaltingNumber", action = "Multientryexit: Returns the subscription results for the last time step and the given detector.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getLastStepHaltingNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepHaltingNumber")
    @ResponseWrapper(localName = "Multientryexit_getLastStepHaltingNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepHaltingNumberResponse")
    @Action(input = "Multientryexit: Returns the subscription results for the last time step and the given detector.", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getLastStepHaltingNumberResponse")
    public int multientryexitGetLastStepHaltingNumber(
        @WebParam(name = "detID", targetNamespace = "")
        String detID);

    /**
     * 
     * @param detID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Multientryexit_getLastStepMeanSpeed", action = "Multientryexit: getLastStepMeanSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getLastStepMeanSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepMeanSpeed")
    @ResponseWrapper(localName = "Multientryexit_getLastStepMeanSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepMeanSpeedResponse")
    @Action(input = "Multientryexit: getLastStepMeanSpeed", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getLastStepMeanSpeedResponse")
    public double multientryexitGetLastStepMeanSpeed(
        @WebParam(name = "detID", targetNamespace = "")
        String detID);

    /**
     * 
     * @param detID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Multientryexit_getLastStepVehicleIDs", action = "Multientryexit: getLastStepVehicleIDs")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getLastStepVehicleIDs", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepVehicleIDs")
    @ResponseWrapper(localName = "Multientryexit_getLastStepVehicleIDsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepVehicleIDsResponse")
    @Action(input = "Multientryexit: getLastStepVehicleIDs", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getLastStepVehicleIDsResponse")
    public List<String> multientryexitGetLastStepVehicleIDs(
        @WebParam(name = "detID", targetNamespace = "")
        String detID);

    /**
     * 
     * @param detID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Multientryexit_getLastStepVehicleNumber", action = "Multientryexit: getLastStepVehicleNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getLastStepVehicleNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepVehicleNumber")
    @ResponseWrapper(localName = "Multientryexit_getLastStepVehicleNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetLastStepVehicleNumberResponse")
    @Action(input = "Multientryexit: getLastStepVehicleNumber", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getLastStepVehicleNumberResponse")
    public int multientryexitGetLastStepVehicleNumber(
        @WebParam(name = "detID", targetNamespace = "")
        String detID);

    /**
     * 
     * @param loopID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "ArealDetector_getJamLengthVehicle", action = "ArealDetector: getJamLengthVehicle")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "ArealDetector_getJamLengthVehicle", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetJamLengthVehicle")
    @ResponseWrapper(localName = "ArealDetector_getJamLengthVehicleResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetJamLengthVehicleResponse")
    @Action(input = "ArealDetector: getJamLengthVehicle", output = "http://ws.tudresden.de/Service_Impl/ArealDetector_getJamLengthVehicleResponse")
    public int arealDetectorGetJamLengthVehicle(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @param loopID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "ArealDetector_getJamLengthMeters", action = "ArealDetector: getJamLengthMeters")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "ArealDetector_getJamLengthMeters", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetJamLengthMeters")
    @ResponseWrapper(localName = "ArealDetector_getJamLengthMetersResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetJamLengthMetersResponse")
    @Action(input = "ArealDetector: getJamLengthMeters", output = "http://ws.tudresden.de/Service_Impl/ArealDetector_getJamLengthMetersResponse")
    public double arealDetectorGetJamLengthMeters(
        @WebParam(name = "loopID", targetNamespace = "")
        String loopID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getParkingEndingVehiclesIDList", action = "Simulation: getParkingEndingVehiclesIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getParkingEndingVehiclesIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingEndingVehiclesIDList")
    @ResponseWrapper(localName = "Simulation_getParkingEndingVehiclesIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingEndingVehiclesIDListResponse")
    @Action(input = "Simulation: getParkingEndingVehiclesIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getParkingEndingVehiclesIDListResponse")
    public List<String> simulationGetParkingEndingVehiclesIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getParkingEndingVehiclesNumber", action = "Simulation: getParkingEndingVehiclesNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getParkingEndingVehiclesNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingEndingVehiclesNumber")
    @ResponseWrapper(localName = "Simulation_getParkingEndingVehiclesNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingEndingVehiclesNumberResponse")
    @Action(input = "Simulation: getParkingEndingVehiclesNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getParkingEndingVehiclesNumberResponse")
    public int simulationGetParkingEndingVehiclesNumber();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getParkingStartingVehiclesIDList", action = "Simulation: getParkingStartingVehiclesIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getParkingStartingVehiclesIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingStartingVehiclesIDList")
    @ResponseWrapper(localName = "Simulation_getParkingStartingVehiclesIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingStartingVehiclesIDListResponse")
    @Action(input = "Simulation: getParkingStartingVehiclesIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getParkingStartingVehiclesIDListResponse")
    public List<String> simulationGetParkingStartingVehiclesIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getParkingStartingVehiclesNumber", action = "Simulation: getParkingStartingVehiclesNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getParkingStartingVehiclesNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingStartingVehiclesNumber")
    @ResponseWrapper(localName = "Simulation_getParkingStartingVehiclesNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetParkingStartingVehiclesNumberResponse")
    @Action(input = "Simulation: getParkingStartingVehiclesNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getParkingStartingVehiclesNumberResponse")
    public int simulationGetParkingStartingVehiclesNumber();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getStopEndingVehiclesIDList", action = "Simulation: getStopEndingVehiclesIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStopEndingVehiclesIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopEndingVehiclesIDList")
    @ResponseWrapper(localName = "Simulation_getStopEndingVehiclesIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopEndingVehiclesIDListResponse")
    @Action(input = "Simulation: getStopEndingVehiclesIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStopEndingVehiclesIDListResponse")
    public List<String> simulationGetStopEndingVehiclesIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getStopEndingVehiclesNumber", action = "Simulation: getStopEndingVehiclesNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStopEndingVehiclesNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopEndingVehiclesNumber")
    @ResponseWrapper(localName = "Simulation_getStopEndingVehiclesNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopEndingVehiclesNumberResponse")
    @Action(input = "Simulation: getStopEndingVehiclesNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStopEndingVehiclesNumberResponse")
    public int simulationGetStopEndingVehiclesNumber();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getStopStartingVehiclesIDList", action = "Simulation: getStopStartingVehiclesIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStopStartingVehiclesIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopStartingVehiclesIDList")
    @ResponseWrapper(localName = "Simulation_getStopStartingVehiclesIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopStartingVehiclesIDListResponse")
    @Action(input = "Simulation: getStopStartingVehiclesIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStopStartingVehiclesIDListResponse")
    public List<String> simulationGetStopStartingVehiclesIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getStopStartingVehiclesNumber", action = "Simulation: getStopStartingVehiclesNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getStopStartingVehiclesNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopStartingVehiclesNumber")
    @ResponseWrapper(localName = "Simulation_getStopStartingVehiclesNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetStopStartingVehiclesNumberResponse")
    @Action(input = "Simulation: getStopStartingVehiclesNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getStopStartingVehiclesNumberResponse")
    public int simulationGetStopStartingVehiclesNumber();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getEndingTeleportIDList", action = "Simulation: getEndingTeleportIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getEndingTeleportIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetEndingTeleportIDList")
    @ResponseWrapper(localName = "Simulation_getEndingTeleportIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetEndingTeleportIDListResponse")
    @Action(input = "Simulation: getEndingTeleportIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getEndingTeleportIDListResponse")
    public List<String> simulationGetEndingTeleportIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getEndingTeleportNumber", action = "Simulation: getEndingTeleportNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getEndingTeleportNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetEndingTeleportNumber")
    @ResponseWrapper(localName = "Simulation_getEndingTeleportNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetEndingTeleportNumberResponse")
    @Action(input = "Simulation: getEndingTeleportNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getEndingTeleportNumberResponse")
    public int simulationGetEndingTeleportNumber();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getMinExpectedNumber", action = "Simulation: getMinExpectedNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getMinExpectedNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetMinExpectedNumber")
    @ResponseWrapper(localName = "Simulation_getMinExpectedNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetMinExpectedNumberResponse")
    @Action(input = "Simulation: getMinExpectedNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getMinExpectedNumberResponse")
    public int simulationGetMinExpectedNumber();

    /**
     * 
     * @param edgeID
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_changeTarget", action = "Vehicle: changeTarget")
    @RequestWrapper(localName = "Vehicle_changeTarget", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleChangeTarget")
    @ResponseWrapper(localName = "Vehicle_changeTargetResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleChangeTargetResponse")
    @Action(input = "Vehicle: changeTarget", output = "http://ws.tudresden.de/Service_Impl/Vehicle_changeTargetResponse")
    public void vehicleChangeTarget(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param laneID
     * @param vehID
     * @param pos
     */
    @WebMethod(operationName = "Vehicle_moveTo", action = "Vehicle: moveTo")
    @RequestWrapper(localName = "Vehicle_moveTo", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleMoveTo")
    @ResponseWrapper(localName = "Vehicle_moveToResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleMoveToResponse")
    @Action(input = "Vehicle: moveTo", output = "http://ws.tudresden.de/Service_Impl/Vehicle_moveToResponse")
    public void vehicleMoveTo(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID,
        @WebParam(name = "pos", targetNamespace = "")
        double pos);

    /**
     * 
     * @param edgeID
     * @param vehID
     * @param y
     * @param x
     * @param lane
     */
    @WebMethod(operationName = "Vehicle_moveToVTD", action = "Vehicle: moveToVTD")
    @RequestWrapper(localName = "Vehicle_moveToVTD", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleMoveToVTD")
    @ResponseWrapper(localName = "Vehicle_moveToVTDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleMoveToVTDResponse")
    @Action(input = "Vehicle: moveToVTD", output = "http://ws.tudresden.de/Service_Impl/Vehicle_moveToVTDResponse")
    public void vehicleMoveToVTD(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "lane", targetNamespace = "")
        int lane,
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y);

    /**
     * 
     * @param reason
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_remove", action = "Vehicle: Remove vehicle with the given ID for the give reason.  Reasons are defined in module constants and start with REMOVE_")
    @RequestWrapper(localName = "Vehicle_remove", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRemove")
    @ResponseWrapper(localName = "Vehicle_removeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRemoveResponse")
    @Action(input = "Vehicle: Remove vehicle with the given ID for the give reason.  Reasons are defined in module constants and start with REMOVE_", output = "http://ws.tudresden.de/Service_Impl/Vehicle_removeResponse")
    public void vehicleRemove(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "reason", targetNamespace = "")
        byte reason);

    /**
     * 
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_rerouteEffort", action = "Vehicle: rerouteEffort")
    @RequestWrapper(localName = "Vehicle_rerouteEffort", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRerouteEffort")
    @ResponseWrapper(localName = "Vehicle_rerouteEffortResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRerouteEffortResponse")
    @Action(input = "Vehicle: rerouteEffort", output = "http://ws.tudresden.de/Service_Impl/Vehicle_rerouteEffortResponse")
    public void vehicleRerouteEffort(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_rerouteTraveltime", action = "Vehicle: rerouteTraveltime")
    @RequestWrapper(localName = "Vehicle_rerouteTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRerouteTraveltime")
    @ResponseWrapper(localName = "Vehicle_rerouteTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleRerouteTraveltimeResponse")
    @Action(input = "Vehicle: rerouteTraveltime", output = "http://ws.tudresden.de/Service_Impl/Vehicle_rerouteTraveltimeResponse")
    public void vehicleRerouteTraveltime(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param accel
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setAccel", action = "Vehicle: setAccel")
    @RequestWrapper(localName = "Vehicle_setAccel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetAccel")
    @ResponseWrapper(localName = "Vehicle_setAccelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetAccelResponse")
    @Action(input = "Vehicle: setAccel", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setAccelResponse")
    public void vehicleSetAccel(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "accel", targetNamespace = "")
        double accel);

    /**
     * 
     * @param time
     * @param edgeID
     * @param endTime
     * @param begTime
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setAdaptedTraveltime", action = "Vehicle: setAdaptedTraveltime")
    @RequestWrapper(localName = "Vehicle_setAdaptedTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetAdaptedTraveltime")
    @ResponseWrapper(localName = "Vehicle_setAdaptedTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetAdaptedTraveltimeResponse")
    @Action(input = "Vehicle: setAdaptedTraveltime", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setAdaptedTraveltimeResponse")
    public void vehicleSetAdaptedTraveltime(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "begTime", targetNamespace = "")
        int begTime,
        @WebParam(name = "endTime", targetNamespace = "")
        int endTime,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "time", targetNamespace = "")
        double time);

    /**
     * 
     * @param color
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setColor", action = "Vehicle: setColor")
    @RequestWrapper(localName = "Vehicle_setColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetColor")
    @ResponseWrapper(localName = "Vehicle_setColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetColorResponse")
    @Action(input = "Vehicle: setColor", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setColorResponse")
    public void vehicleSetColor(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color);

    /**
     * 
     * @param decel
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setDecel", action = "Vehicle: setDecel")
    @RequestWrapper(localName = "Vehicle_setDecel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetDecel")
    @ResponseWrapper(localName = "Vehicle_setDecelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetDecelResponse")
    @Action(input = "Vehicle: setDecel", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setDecelResponse")
    public void vehicleSetDecel(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "decel", targetNamespace = "")
        double decel);

    /**
     * 
     * @param edgeID
     * @param effort
     * @param endTime
     * @param begTime
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setEffort", action = "Vehicle: setEffort")
    @RequestWrapper(localName = "Vehicle_setEffort", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetEffort")
    @ResponseWrapper(localName = "Vehicle_setEffortResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetEffortResponse")
    @Action(input = "Vehicle: setEffort", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setEffortResponse")
    public void vehicleSetEffort(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "begTime", targetNamespace = "")
        int begTime,
        @WebParam(name = "endTime", targetNamespace = "")
        int endTime,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "effort", targetNamespace = "")
        double effort);

    /**
     * 
     * @param vehID
     * @param clazz
     */
    @WebMethod(operationName = "Vehicle_setEmissionClass", action = "Vehicle: setEmissionClass")
    @RequestWrapper(localName = "Vehicle_setEmissionClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetEmissionClass")
    @ResponseWrapper(localName = "Vehicle_setEmissionClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetEmissionClassResponse")
    @Action(input = "Vehicle: setEmissionClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setEmissionClassResponse")
    public void vehicleSetEmissionClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param imperfection
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setImperfection", action = "Vehicle: setImperfection")
    @RequestWrapper(localName = "Vehicle_setImperfection", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetImperfection")
    @ResponseWrapper(localName = "Vehicle_setImperfectionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetImperfectionResponse")
    @Action(input = "Vehicle: setImperfection", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setImperfectionResponse")
    public void vehicleSetImperfection(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "imperfection", targetNamespace = "")
        double imperfection);

    /**
     * 
     * @param length
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setLength", action = "Vehicle: setLength")
    @RequestWrapper(localName = "Vehicle_setLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetLength")
    @ResponseWrapper(localName = "Vehicle_setLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetLengthResponse")
    @Action(input = "Vehicle: setLength", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setLengthResponse")
    public void vehicleSetLength(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "length", targetNamespace = "")
        double length);

    /**
     * 
     * @param speed
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setMaxSpeed", action = "Vehicle: setMaxSpeed")
    @RequestWrapper(localName = "Vehicle_setMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetMaxSpeed")
    @ResponseWrapper(localName = "Vehicle_setMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetMaxSpeedResponse")
    @Action(input = "Vehicle: setMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setMaxSpeedResponse")
    public void vehicleSetMaxSpeed(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed);

    /**
     * 
     * @param minGap
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setMinGap", action = "Vehicle: setMinGap")
    @RequestWrapper(localName = "Vehicle_setMinGap", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetMinGap")
    @ResponseWrapper(localName = "Vehicle_setMinGapResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetMinGapResponse")
    @Action(input = "Vehicle: setMinGap", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setMinGapResponse")
    public void vehicleSetMinGap(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "minGap", targetNamespace = "")
        double minGap);

    /**
     * 
     * @param routeID
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setRouteID", action = "Vehicle: setRouteID")
    @RequestWrapper(localName = "Vehicle_setRouteID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetRouteID")
    @ResponseWrapper(localName = "Vehicle_setRouteIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetRouteIDResponse")
    @Action(input = "Vehicle: setRouteID", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setRouteIDResponse")
    public void vehicleSetRouteID(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "routeID", targetNamespace = "")
        String routeID);

    /**
     * 
     * @param vehID
     * @param clazz
     */
    @WebMethod(operationName = "Vehicle_setShapeClass", action = "Vehicle: setShapeClass")
    @RequestWrapper(localName = "Vehicle_setShapeClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetShapeClass")
    @ResponseWrapper(localName = "Vehicle_setShapeClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetShapeClassResponse")
    @Action(input = "Vehicle: setShapeClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setShapeClassResponse")
    public void vehicleSetShapeClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param vehID
     * @param signals
     */
    @WebMethod(operationName = "Vehicle_setSignals", action = "Vehicle: setSignals")
    @RequestWrapper(localName = "Vehicle_setSignals", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSignals")
    @ResponseWrapper(localName = "Vehicle_setSignalsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSignalsResponse")
    @Action(input = "Vehicle: setSignals", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setSignalsResponse")
    public void vehicleSetSignals(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "signals", targetNamespace = "")
        String signals);

    /**
     * 
     * @param speed
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setSpeed", action = "Vehicle: setSpeed")
    @RequestWrapper(localName = "Vehicle_setSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeed")
    @ResponseWrapper(localName = "Vehicle_setSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeedResponse")
    @Action(input = "Vehicle: setSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setSpeedResponse")
    public void vehicleSetSpeed(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed);

    /**
     * 
     * @param deviation
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setSpeedDeviation", action = "Vehicle: setSpeedDeviation")
    @RequestWrapper(localName = "Vehicle_setSpeedDeviation", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeedDeviation")
    @ResponseWrapper(localName = "Vehicle_setSpeedDeviationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeedDeviationResponse")
    @Action(input = "Vehicle: setSpeedDeviation", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setSpeedDeviationResponse")
    public void vehicleSetSpeedDeviation(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "deviation", targetNamespace = "")
        double deviation);

    /**
     * 
     * @param factor
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setSpeedFactor", action = "Vehicle: setSpeedFactor")
    @RequestWrapper(localName = "Vehicle_setSpeedFactor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeedFactor")
    @ResponseWrapper(localName = "Vehicle_setSpeedFactorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetSpeedFactorResponse")
    @Action(input = "Vehicle: setSpeedFactor", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setSpeedFactorResponse")
    public void vehicleSetSpeedFactor(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "factor", targetNamespace = "")
        double factor);

    /**
     * 
     * @param duration
     * @param edgeID
     * @param laneIndex
     * @param vehID
     * @param pos
     */
    @WebMethod(operationName = "Vehicle_setStop", action = "Vehicle: setStop")
    @RequestWrapper(localName = "Vehicle_setStop", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetStop")
    @ResponseWrapper(localName = "Vehicle_setStopResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetStopResponse")
    @Action(input = "Vehicle: setStop", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setStopResponse")
    public void vehicleSetStop(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "pos", targetNamespace = "")
        double pos,
        @WebParam(name = "laneIndex", targetNamespace = "")
        byte laneIndex,
        @WebParam(name = "duration", targetNamespace = "")
        int duration);

    /**
     * 
     * @param tau
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setTau", action = "Vehicle: setTau")
    @RequestWrapper(localName = "Vehicle_setTau", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetTau")
    @ResponseWrapper(localName = "Vehicle_setTauResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetTauResponse")
    @Action(input = "Vehicle: setTau", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setTauResponse")
    public void vehicleSetTau(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "tau", targetNamespace = "")
        double tau);

    /**
     * 
     * @param vehID
     * @param clazz
     */
    @WebMethod(operationName = "Vehicle_setVehicleClass", action = "Vehicle: setVehicleClass")
    @RequestWrapper(localName = "Vehicle_setVehicleClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetVehicleClass")
    @ResponseWrapper(localName = "Vehicle_setVehicleClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetVehicleClassResponse")
    @Action(input = "Vehicle: setVehicleClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setVehicleClassResponse")
    public void vehicleSetVehicleClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param width
     * @param vehID
     */
    @WebMethod(operationName = "Vehicle_setWidth", action = "Vehicle: setWidth")
    @RequestWrapper(localName = "Vehicle_setWidth", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetWidth")
    @ResponseWrapper(localName = "Vehicle_setWidthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetWidthResponse")
    @Action(input = "Vehicle: setWidth", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setWidthResponse")
    public void vehicleSetWidth(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "width", targetNamespace = "")
        double width);

    /**
     * 
     * @param index
     * @param tlsID
     */
    @WebMethod(operationName = "Trafficlights_setPhase", action = "Trafficlights: setPhase")
    @RequestWrapper(localName = "Trafficlights_setPhase", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetPhase")
    @ResponseWrapper(localName = "Trafficlights_setPhaseResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetPhaseResponse")
    @Action(input = "Trafficlights: setPhase", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_setPhaseResponse")
    public void trafficlightsSetPhase(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID,
        @WebParam(name = "index", targetNamespace = "")
        int index);

    /**
     * 
     * @param programID
     * @param tlsID
     */
    @WebMethod(operationName = "Trafficlights_setProgram", action = "Trafficlights: setProgram")
    @RequestWrapper(localName = "Trafficlights_setProgram", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetProgram")
    @ResponseWrapper(localName = "Trafficlights_setProgramResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsSetProgramResponse")
    @Action(input = "Trafficlights: setProgram", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_setProgramResponse")
    public void trafficlightsSetProgram(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID,
        @WebParam(name = "programID", targetNamespace = "")
        String programID);

    /**
     * 
     * @param accel
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setAccel", action = "Vehicletype: setAccel")
    @RequestWrapper(localName = "Vehicletype_setAccel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetAccel")
    @ResponseWrapper(localName = "Vehicletype_setAccelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetAccelResponse")
    @Action(input = "Vehicletype: setAccel", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setAccelResponse")
    public void vehicletypeSetAccel(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "accel", targetNamespace = "")
        double accel);

    /**
     * 
     * @param color
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setColor", action = "Vehicletype: setColor")
    @RequestWrapper(localName = "Vehicletype_setColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetColor")
    @ResponseWrapper(localName = "Vehicletype_setColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetColorResponse")
    @Action(input = "Vehicletype: setColor", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setColorResponse")
    public void vehicletypeSetColor(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color);

    /**
     * 
     * @param decel
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setDecel", action = "Vehicletype: setDecel")
    @RequestWrapper(localName = "Vehicletype_setDecel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetDecel")
    @ResponseWrapper(localName = "Vehicletype_setDecelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetDecelResponse")
    @Action(input = "Vehicletype: setDecel", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setDecelResponse")
    public void vehicletypeSetDecel(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "decel", targetNamespace = "")
        double decel);

    /**
     * 
     * @param clazz
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setEmissionClass", action = "Vehicletype: setEmissionClass")
    @RequestWrapper(localName = "Vehicletype_setEmissionClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetEmissionClass")
    @ResponseWrapper(localName = "Vehicletype_setEmissionClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetEmissionClassResponse")
    @Action(input = "Vehicletype: setEmissionClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setEmissionClassResponse")
    public void vehicletypeSetEmissionClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param imperfection
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setImperfection", action = "Vehicletype: setImperfection")
    @RequestWrapper(localName = "Vehicletype_setImperfection", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetImperfection")
    @ResponseWrapper(localName = "Vehicletype_setImperfectionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetImperfectionResponse")
    @Action(input = "Vehicletype: setImperfection", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setImperfectionResponse")
    public void vehicletypeSetImperfection(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "imperfection", targetNamespace = "")
        double imperfection);

    /**
     * 
     * @param length
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setLength", action = "Vehicletype: setLength")
    @RequestWrapper(localName = "Vehicletype_setLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetLength")
    @ResponseWrapper(localName = "Vehicletype_setLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetLengthResponse")
    @Action(input = "Vehicletype: setLength", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setLengthResponse")
    public void vehicletypeSetLength(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "length", targetNamespace = "")
        double length);

    /**
     * 
     * @param speed
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setMaxSpeed", action = "Vehicletype: setMaxSpeed")
    @RequestWrapper(localName = "Vehicletype_setMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetMaxSpeed")
    @ResponseWrapper(localName = "Vehicletype_setMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetMaxSpeedResponse")
    @Action(input = "Vehicletype: setMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setMaxSpeedResponse")
    public void vehicletypeSetMaxSpeed(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed);

    /**
     * 
     * @param minGap
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setMinGap", action = "Vehicletype: setMinGap")
    @RequestWrapper(localName = "Vehicletype_setMinGap", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetMinGap")
    @ResponseWrapper(localName = "Vehicletype_setMinGapResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetMinGapResponse")
    @Action(input = "Vehicletype: setMinGap", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setMinGapResponse")
    public void vehicletypeSetMinGap(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "minGap", targetNamespace = "")
        double minGap);

    /**
     * 
     * @param clazz
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setShapeClass", action = "Vehicletype: setShapeClass")
    @RequestWrapper(localName = "Vehicletype_setShapeClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetShapeClass")
    @ResponseWrapper(localName = "Vehicletype_setShapeClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetShapeClassResponse")
    @Action(input = "Vehicletype: setShapeClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setShapeClassResponse")
    public void vehicletypeSetShapeClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param deviation
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setSpeedDeviation", action = "Vehicletype: setSpeedDeviation")
    @RequestWrapper(localName = "Vehicletype_setSpeedDeviation", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetSpeedDeviation")
    @ResponseWrapper(localName = "Vehicletype_setSpeedDeviationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetSpeedDeviationResponse")
    @Action(input = "Vehicletype: setSpeedDeviation", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setSpeedDeviationResponse")
    public void vehicletypeSetSpeedDeviation(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "deviation", targetNamespace = "")
        double deviation);

    /**
     * 
     * @param factor
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setSpeedFactor", action = "Vehicletype: setSpeedFactor")
    @RequestWrapper(localName = "Vehicletype_setSpeedFactor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetSpeedFactor")
    @ResponseWrapper(localName = "Vehicletype_setSpeedFactorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetSpeedFactorResponse")
    @Action(input = "Vehicletype: setSpeedFactor", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setSpeedFactorResponse")
    public void vehicletypeSetSpeedFactor(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "factor", targetNamespace = "")
        double factor);

    /**
     * 
     * @param tau
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setTau", action = "Vehicletype: setTau")
    @RequestWrapper(localName = "Vehicletype_setTau", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetTau")
    @ResponseWrapper(localName = "Vehicletype_setTauResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetTauResponse")
    @Action(input = "Vehicletype: setTau", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setTauResponse")
    public void vehicletypeSetTau(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "tau", targetNamespace = "")
        double tau);

    /**
     * 
     * @param clazz
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setVehicleClass", action = "Vehicletype: setVehicleClass")
    @RequestWrapper(localName = "Vehicletype_setVehicleClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetVehicleClass")
    @ResponseWrapper(localName = "Vehicletype_setVehicleClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetVehicleClassResponse")
    @Action(input = "Vehicletype: setVehicleClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setVehicleClassResponse")
    public void vehicletypeSetVehicleClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "clazz", targetNamespace = "")
        String clazz);

    /**
     * 
     * @param width
     * @param typeID
     */
    @WebMethod(operationName = "Vehicletype_setWidth", action = "Vehicletype: setWidth")
    @RequestWrapper(localName = "Vehicletype_setWidth", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetWidth")
    @ResponseWrapper(localName = "Vehicletype_setWidthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeSetWidthResponse")
    @Action(input = "Vehicletype: setWidth", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_setWidthResponse")
    public void vehicletypeSetWidth(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID,
        @WebParam(name = "width", targetNamespace = "")
        double width);

    /**
     * 
     * @param allowedClasses
     * @param laneID
     */
    @WebMethod(operationName = "Lane_setAllowed", action = "Lane: setAllowed")
    @RequestWrapper(localName = "Lane_setAllowed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetAllowed")
    @ResponseWrapper(localName = "Lane_setAllowedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetAllowedResponse")
    @Action(input = "Lane: setAllowed", output = "http://ws.tudresden.de/Service_Impl/Lane_setAllowedResponse")
    public void laneSetAllowed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID,
        @WebParam(name = "allowedClasses", targetNamespace = "")
        List<String> allowedClasses);

    /**
     * 
     * @param laneID
     * @param disallowedClasses
     */
    @WebMethod(operationName = "Lane_setDisallowed", action = "Lane: setDisallowed")
    @RequestWrapper(localName = "Lane_setDisallowed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetDisallowed")
    @ResponseWrapper(localName = "Lane_setDisallowedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetDisallowedResponse")
    @Action(input = "Lane: setDisallowed", output = "http://ws.tudresden.de/Service_Impl/Lane_setDisallowedResponse")
    public void laneSetDisallowed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID,
        @WebParam(name = "disallowedClasses", targetNamespace = "")
        List<String> disallowedClasses);

    /**
     * 
     * @param laneID
     * @param length
     */
    @WebMethod(operationName = "Lane_setLength", action = "Lane: setLength")
    @RequestWrapper(localName = "Lane_setLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetLength")
    @ResponseWrapper(localName = "Lane_setLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetLengthResponse")
    @Action(input = "Lane: setLength", output = "http://ws.tudresden.de/Service_Impl/Lane_setLengthResponse")
    public void laneSetLength(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID,
        @WebParam(name = "length", targetNamespace = "")
        double length);

    /**
     * 
     * @param laneID
     * @param speed
     */
    @WebMethod(operationName = "Lane_setMaxSpeed", action = "Lane: setMaxSpeed")
    @RequestWrapper(localName = "Lane_setMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetMaxSpeed")
    @ResponseWrapper(localName = "Lane_setMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneSetMaxSpeedResponse")
    @Action(input = "Lane: setMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Lane_setMaxSpeedResponse")
    public void laneSetMaxSpeed(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed);

    /**
     * 
     * @param layer
     * @param polygonID
     */
    @WebMethod(operationName = "Polygon_remove", action = "Polygon: remove")
    @RequestWrapper(localName = "Polygon_remove", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonRemove")
    @ResponseWrapper(localName = "Polygon_removeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonRemoveResponse")
    @Action(input = "Polygon: remove", output = "http://ws.tudresden.de/Service_Impl/Polygon_removeResponse")
    public void polygonRemove(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID,
        @WebParam(name = "layer", targetNamespace = "")
        int layer);

    /**
     * 
     * @param color
     * @param polygonID
     */
    @WebMethod(operationName = "Polygon_setColor", action = "Polygon: setColor")
    @RequestWrapper(localName = "Polygon_setColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetColor")
    @ResponseWrapper(localName = "Polygon_setColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetColorResponse")
    @Action(input = "Polygon: setColor", output = "http://ws.tudresden.de/Service_Impl/Polygon_setColorResponse")
    public void polygonSetColor(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color);

    /**
     * 
     * @param shape
     * @param polygonID
     */
    @WebMethod(operationName = "Polygon_setShape", action = "Polygon: setShape")
    @RequestWrapper(localName = "Polygon_setShape", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetShape")
    @ResponseWrapper(localName = "Polygon_setShapeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetShapeResponse")
    @Action(input = "Polygon: setShape", output = "http://ws.tudresden.de/Service_Impl/Polygon_setShapeResponse")
    public void polygonSetShape(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID,
        @WebParam(name = "shape", targetNamespace = "")
        List<String> shape);

    /**
     * 
     * @param polygonID
     * @param polygonType
     */
    @WebMethod(operationName = "Polygon_setType", action = "Polygon: setType")
    @RequestWrapper(localName = "Polygon_setType", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetType")
    @ResponseWrapper(localName = "Polygon_setTypeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PolygonSetTypeResponse")
    @Action(input = "Polygon: setType", output = "http://ws.tudresden.de/Service_Impl/Polygon_setTypeResponse")
    public void polygonSetType(
        @WebParam(name = "polygonID", targetNamespace = "")
        String polygonID,
        @WebParam(name = "polygonType", targetNamespace = "")
        String polygonType);

    /**
     * 
     * @param poiID
     * @param y
     * @param x
     */
    @WebMethod(operationName = "Poi_setPosition", action = "Poi: setPosition")
    @RequestWrapper(localName = "Poi_setPosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetPosition")
    @ResponseWrapper(localName = "Poi_setPositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiSetPositionResponse")
    @Action(input = "Poi: setPosition", output = "http://ws.tudresden.de/Service_Impl/Poi_setPositionResponse")
    public void poiSetPosition(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID,
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y);

    /**
     * 
     * @param filename
     * @param viewID
     */
    @WebMethod(operationName = "GUI_screenshot", action = "Gui: screenshot")
    @RequestWrapper(localName = "GUI_screenshot", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIScreenshot")
    @ResponseWrapper(localName = "GUI_screenshotResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIScreenshotResponse")
    @Action(input = "Gui: screenshot", output = "http://ws.tudresden.de/Service_Impl/GUI_screenshotResponse")
    public void guiScreenshot(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "filename", targetNamespace = "")
        String filename);

    /**
     * 
     * @param ymin
     * @param ymax
     * @param xmin
     * @param viewID
     * @param xmax
     */
    @WebMethod(operationName = "GUI_setBoundary", action = "Gui: Set the current boundary for the given view (see getBoundary()).")
    @RequestWrapper(localName = "GUI_setBoundary", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetBoundary")
    @ResponseWrapper(localName = "GUI_setBoundaryResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUISetBoundaryResponse")
    @Action(input = "Gui: Set the current boundary for the given view (see getBoundary()).", output = "http://ws.tudresden.de/Service_Impl/GUI_setBoundaryResponse")
    public void guiSetBoundary(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "xmin", targetNamespace = "")
        double xmin,
        @WebParam(name = "ymin", targetNamespace = "")
        double ymin,
        @WebParam(name = "xmax", targetNamespace = "")
        double xmax,
        @WebParam(name = "ymax", targetNamespace = "")
        double ymax);

    /**
     * 
     * @param vehID
     * @param viewID
     */
    @WebMethod(operationName = "GUI_trackVehicle", action = "Gui: trackVehicle")
    @RequestWrapper(localName = "GUI_trackVehicle", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUITrackVehicle")
    @ResponseWrapper(localName = "GUI_trackVehicleResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUITrackVehicleResponse")
    @Action(input = "Gui: trackVehicle", output = "http://ws.tudresden.de/Service_Impl/GUI_trackVehicleResponse")
    public void guiTrackVehicle(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID,
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Multientryexit_getIDList", action = "Multientryexit: Returns a list of all e3 detectors in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetIDList")
    @ResponseWrapper(localName = "Multientryexit_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetIDListResponse")
    @Action(input = "Multientryexit: Returns a list of all e3 detectors in the network.", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getIDListResponse")
    public List<String> multientryexitGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Multientryexit_getIDCount", action = "Multientryexit: Returns the number of all e3 detectors in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Multientryexit_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetIDCount")
    @ResponseWrapper(localName = "Multientryexit_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.MultientryexitGetIDCountResponse")
    @Action(input = "Multientryexit: Returns the number of all e3 detectors in the network.", output = "http://ws.tudresden.de/Service_Impl/Multientryexit_getIDCountResponse")
    public int multientryexitGetIDCount();

    /**
     * 
     * @param time
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getAdaptedTraveltime", action = "Edge: Returns the travel time value (in s) used for (re-)routing")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getAdaptedTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetAdaptedTraveltime")
    @ResponseWrapper(localName = "Edge_getAdaptedTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetAdaptedTraveltimeResponse")
    @Action(input = "Edge: Returns the travel time value (in s) used for (re-)routing", output = "http://ws.tudresden.de/Service_Impl/Edge_getAdaptedTraveltimeResponse")
    public double edgeGetAdaptedTraveltime(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "time", targetNamespace = "")
        double time);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getCO2Emission", action = "Edge: Returns the CO2 emission in mg for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getCO2Emission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetCO2Emission")
    @ResponseWrapper(localName = "Edge_getCO2EmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetCO2EmissionResponse")
    @Action(input = "Edge: Returns the CO2 emission in mg for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getCO2EmissionResponse")
    public double edgeGetCO2Emission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getCOEmission", action = "Edge: Returns the CO emission in mg for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getCOEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetCOEmission")
    @ResponseWrapper(localName = "Edge_getCOEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetCOEmissionResponse")
    @Action(input = "Edge: Returns the CO emission in mg for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getCOEmissionResponse")
    public double edgeGetCOEmission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param time
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getEffort", action = "Edge: Returns the effort value used for (re-)routing")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getEffort", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetEffort")
    @ResponseWrapper(localName = "Edge_getEffortResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetEffortResponse")
    @Action(input = "Edge: Returns the effort value used for (re-)routing", output = "http://ws.tudresden.de/Service_Impl/Edge_getEffortResponse")
    public double edgeGetEffort(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "time", targetNamespace = "")
        double time);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getFuelConsumption", action = "Edge: Returns the fuel consumption in ml for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getFuelConsumption", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetFuelConsumption")
    @ResponseWrapper(localName = "Edge_getFuelConsumptionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetFuelConsumptionResponse")
    @Action(input = "Edge: Returns the fuel consumption in ml for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getFuelConsumptionResponse")
    public double edgeGetFuelConsumption(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getHCEmission", action = "Edge: Returns the HC emission in mg for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getHCEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetHCEmission")
    @ResponseWrapper(localName = "Edge_getHCEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetHCEmissionResponse")
    @Action(input = "Edge: Returns the HC emission in mg for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getHCEmissionResponse")
    public double edgeGetHCEmission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Edge_getIDCount", action = "Edge: Returns the number of edges in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetIDCount")
    @ResponseWrapper(localName = "Edge_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetIDCountResponse")
    @Action(input = "Edge: Returns the number of edges in the network.", output = "http://ws.tudresden.de/Service_Impl/Edge_getIDCountResponse")
    public int edgeGetIDCount();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Edge_getIDList", action = "Edge: Returns a list of all edges in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetIDList")
    @ResponseWrapper(localName = "Edge_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetIDListResponse")
    @Action(input = "Edge: Returns a list of all edges in the network.", output = "http://ws.tudresden.de/Service_Impl/Edge_getIDListResponse")
    public List<String> edgeGetIDList();

    /**
     * 
     * @param edgeID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Edge_getLastStepHaltingNumber", action = "Edge: Returns the total number of halting vehicles for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepHaltingNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepHaltingNumber")
    @ResponseWrapper(localName = "Edge_getLastStepHaltingNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepHaltingNumberResponse")
    @Action(input = "Edge: Returns the total number of halting vehicles for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepHaltingNumberResponse")
    public int edgeGetLastStepHaltingNumber(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getLastStepLength", action = "Edge: Returns the total vehicle length in m for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepLength")
    @ResponseWrapper(localName = "Edge_getLastStepLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepLengthResponse")
    @Action(input = "Edge: Returns the total vehicle length in m for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepLengthResponse")
    public double edgeGetLastStepLength(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getLastStepMeanSpeed", action = "Edge: Returns the average speed in m/s for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepMeanSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepMeanSpeed")
    @ResponseWrapper(localName = "Edge_getLastStepMeanSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepMeanSpeedResponse")
    @Action(input = "Edge: Returns the average speed in m/s for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepMeanSpeedResponse")
    public double edgeGetLastStepMeanSpeed(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getLastStepOccupancy", action = "Edge: Returns the occupancy in % for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepOccupancy", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepOccupancy")
    @ResponseWrapper(localName = "Edge_getLastStepOccupancyResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepOccupancyResponse")
    @Action(input = "Edge: Returns the occupancy in % for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepOccupancyResponse")
    public double edgeGetLastStepOccupancy(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Edge_getLastStepVehicleIDs", action = "Edge: Returns the subscription results for the last time step and the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepVehicleIDs", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepVehicleIDs")
    @ResponseWrapper(localName = "Edge_getLastStepVehicleIDsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepVehicleIDsResponse")
    @Action(input = "Edge: Returns the subscription results for the last time step and the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepVehicleIDsResponse")
    public List<String> edgeGetLastStepVehicleIDs(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Edge_getLastStepVehicleNumber", action = "Edge: Returns the total number of vehicles for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getLastStepVehicleNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepVehicleNumber")
    @ResponseWrapper(localName = "Edge_getLastStepVehicleNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetLastStepVehicleNumberResponse")
    @Action(input = "Edge: Returns the total number of vehicles for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getLastStepVehicleNumberResponse")
    public int edgeGetLastStepVehicleNumber(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getNOxEmission", action = "Edge: Returns the NOx emission in mg for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getNOxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetNOxEmission")
    @ResponseWrapper(localName = "Edge_getNOxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetNOxEmissionResponse")
    @Action(input = "Edge: Returns the NOx emission in mg for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getNOxEmissionResponse")
    public double edgeGetNOxEmission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getNoiseEmission", action = "Edge: Returns the noise emission in db for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getNoiseEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetNoiseEmission")
    @ResponseWrapper(localName = "Edge_getNoiseEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetNoiseEmissionResponse")
    @Action(input = "Edge: Returns the noise emission in db for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getNoiseEmissionResponse")
    public double edgeGetNoiseEmission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getPMxEmission", action = "Edge: Returns the particular matter emission in mg for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getPMxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetPMxEmission")
    @ResponseWrapper(localName = "Edge_getPMxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetPMxEmissionResponse")
    @Action(input = "Edge: Returns the particular matter emission in mg for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getPMxEmissionResponse")
    public double edgeGetPMxEmission(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getTraveltime", action = "Edge: Returns the estimated travel time in s for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetTraveltime")
    @ResponseWrapper(localName = "Edge_getTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetTraveltimeResponse")
    @Action(input = "Edge: Returns the estimated travel time in s for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getTraveltimeResponse")
    public double edgeGetTraveltime(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param edgeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Edge_getWaitingTime", action = "Edge: Returns the waiting time in s for the last time step on the given edge.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Edge_getWaitingTime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetWaitingTime")
    @ResponseWrapper(localName = "Edge_getWaitingTimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.EdgeGetWaitingTimeResponse")
    @Action(input = "Edge: Returns the waiting time in s for the last time step on the given edge.", output = "http://ws.tudresden.de/Service_Impl/Edge_getWaitingTimeResponse")
    public double edgeGetWaitingTime(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "ArealDetector_getIDList", action = "ArealDetector: getIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "ArealDetector_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetIDList")
    @ResponseWrapper(localName = "ArealDetector_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetIDListResponse")
    @Action(input = "ArealDetector: getIDList", output = "http://ws.tudresden.de/Service_Impl/ArealDetector_getIDListResponse")
    public List<String> arealDetectorGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "ArealDetector_getIDCount", action = "ArealDetector: getIDCount")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "ArealDetector_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetIDCount")
    @ResponseWrapper(localName = "ArealDetector_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.ArealDetectorGetIDCountResponse")
    @Action(input = "ArealDetector: getIDCount", output = "http://ws.tudresden.de/Service_Impl/ArealDetector_getIDCountResponse")
    public int arealDetectorGetIDCount();

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getAccel", action = "Vehicle: getAccel")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getAccel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAccel")
    @ResponseWrapper(localName = "Vehicle_getAccelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAccelResponse")
    @Action(input = "Vehicle: getAccel", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getAccelResponse")
    public double vehicleGetAccel(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param time
     * @param edgeID
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getAdaptedTraveltime", action = "Vehicle: getAdaptedTraveltime")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getAdaptedTraveltime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAdaptedTraveltime")
    @ResponseWrapper(localName = "Vehicle_getAdaptedTraveltimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAdaptedTraveltimeResponse")
    @Action(input = "Vehicle: getAdaptedTraveltime", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getAdaptedTraveltimeResponse")
    public double vehicleGetAdaptedTraveltime(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "time", targetNamespace = "")
        double time,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getAngle", action = "Vehicle: getAngle")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getAngle", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAngle")
    @ResponseWrapper(localName = "Vehicle_getAngleResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAngleResponse")
    @Action(input = "Vehicle: getAngle", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getAngleResponse")
    public double vehicleGetAngle(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Vehicle_getBestLanes", action = "Vehicle: getBestLanes")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getBestLanes", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetBestLanes")
    @ResponseWrapper(localName = "Vehicle_getBestLanesResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetBestLanesResponse")
    @Action(input = "Vehicle: getBestLanes", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getBestLanesResponse")
    public List<String> vehicleGetBestLanes(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getCO2Emission", action = "Vehicle: Returns the CO2 emission in mg for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getCO2Emission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetCO2Emission")
    @ResponseWrapper(localName = "Vehicle_getCO2EmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetCO2EmissionResponse")
    @Action(input = "Vehicle: Returns the CO2 emission in mg for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getCO2EmissionResponse")
    public double vehicleGetCO2Emission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getCOEmission", action = "Vehicle: Returns the CO emission in mg for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getCOEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetCOEmission")
    @ResponseWrapper(localName = "Vehicle_getCOEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetCOEmissionResponse")
    @Action(input = "Vehicle: Returns the CO emission in mg for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getCOEmissionResponse")
    public double vehicleGetCOEmission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns de.tudresden.ws.SumoColor
     */
    @WebMethod(operationName = "Vehicle_getColor", action = "Vehicle: getColor")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetColor")
    @ResponseWrapper(localName = "Vehicle_getColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetColorResponse")
    @Action(input = "Vehicle: getColor", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getColorResponse")
    public SumoColor vehicleGetColor(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getDecel", action = "Vehicle: getDecel")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getDecel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDecel")
    @ResponseWrapper(localName = "Vehicle_getDecelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDecelResponse")
    @Action(input = "Vehicle: getDecel", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getDecelResponse")
    public double vehicleGetDecel(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param laneID
     * @param edgeID
     * @param vehID
     * @param pos
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getDrivingDistance", action = "Vehicle: getDrivingDistance")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getDrivingDistance", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDrivingDistance")
    @ResponseWrapper(localName = "Vehicle_getDrivingDistanceResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDrivingDistanceResponse")
    @Action(input = "Vehicle: getDrivingDistance", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getDrivingDistanceResponse")
    public double vehicleGetDrivingDistance(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "pos", targetNamespace = "")
        double pos,
        @WebParam(name = "laneID", targetNamespace = "")
        int laneID);

    /**
     * 
     * @param vehID
     * @param y
     * @param x
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getDrivingDistance2D", action = "Vehicle: Returns the subscription results for the last time step and the given vehicle.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getDrivingDistance2D", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDrivingDistance2D")
    @ResponseWrapper(localName = "Vehicle_getDrivingDistance2DResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDrivingDistance2DResponse")
    @Action(input = "Vehicle: Returns the subscription results for the last time step and the given vehicle.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getDrivingDistance2DResponse")
    public double vehicleGetDrivingDistance2D(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y);

    /**
     * 
     * @param time
     * @param edgeID
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getEffort", action = "Vehicle: getEffort")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getEffort", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetEffort")
    @ResponseWrapper(localName = "Vehicle_getEffortResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetEffortResponse")
    @Action(input = "Vehicle: getEffort", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getEffortResponse")
    public double vehicleGetEffort(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "time", targetNamespace = "")
        double time,
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getEmissionClass", action = "Vehicle: getEmissionClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getEmissionClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetEmissionClass")
    @ResponseWrapper(localName = "Vehicle_getEmissionClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetEmissionClassResponse")
    @Action(input = "Vehicle: getEmissionClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getEmissionClassResponse")
    public String vehicleGetEmissionClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getFuelConsumption", action = "Vehicle: Returns the fuel consumption in ml for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getFuelConsumption", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetFuelConsumption")
    @ResponseWrapper(localName = "Vehicle_getFuelConsumptionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetFuelConsumptionResponse")
    @Action(input = "Vehicle: Returns the fuel consumption in ml for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getFuelConsumptionResponse")
    public double vehicleGetFuelConsumption(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getHCEmission", action = "Vehicle: Returns the HC emission in mg for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getHCEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetHCEmission")
    @ResponseWrapper(localName = "Vehicle_getHCEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetHCEmissionResponse")
    @Action(input = "Vehicle: Returns the HC emission in mg for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getHCEmissionResponse")
    public double vehicleGetHCEmission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Vehicle_getIDList", action = "Vehicle: Returns a list of all known vehicles.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetIDList")
    @ResponseWrapper(localName = "Vehicle_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetIDListResponse")
    @Action(input = "Vehicle: Returns a list of all known vehicles.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getIDListResponse")
    public List<String> vehicleGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_getIDCount", action = "Vehicle: Returns the number of all known vehicles.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetIDCount")
    @ResponseWrapper(localName = "Vehicle_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetIDCountResponse")
    @Action(input = "Vehicle: Returns the number of all known vehicles.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getIDCountResponse")
    public int vehicleGetIDCount();

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getImperfection", action = "Vehicle: getImperfection")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getImperfection", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetImperfection")
    @ResponseWrapper(localName = "Vehicle_getImperfectionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetImperfectionResponse")
    @Action(input = "Vehicle: getImperfection", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getImperfectionResponse")
    public double vehicleGetImperfection(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getAllowedSpeed", action = "Vehicle: getAllowedSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getAllowedSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAllowedSpeed")
    @ResponseWrapper(localName = "Vehicle_getAllowedSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetAllowedSpeedResponse")
    @Action(input = "Vehicle: getAllowedSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getAllowedSpeedResponse")
    public double vehicleGetAllowedSpeed(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_getPersonNumber", action = "Vehicle: getPersonNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getPersonNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPersonNumber")
    @ResponseWrapper(localName = "Vehicle_getPersonNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPersonNumberResponse")
    @Action(input = "Vehicle: getPersonNumber", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getPersonNumberResponse")
    public int vehicleGetPersonNumber(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getDistance", action = "Vehicle: getDistance")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getDistance", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDistance")
    @ResponseWrapper(localName = "Vehicle_getDistanceResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetDistanceResponse")
    @Action(input = "Vehicle: getDistance", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getDistanceResponse")
    public double vehicleGetDistance(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getWaitingTime", action = "Vehicle: getWaitingTime")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getWaitingTime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetWaitingTime")
    @ResponseWrapper(localName = "Vehicle_getWaitingTimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetWaitingTimeResponse")
    @Action(input = "Vehicle: getWaitingTime", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getWaitingTimeResponse")
    public double vehicleGetWaitingTime(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getLaneID", action = "Vehicle: getLaneID")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getLaneID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLaneID")
    @ResponseWrapper(localName = "Vehicle_getLaneIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLaneIDResponse")
    @Action(input = "Vehicle: getLaneID", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getLaneIDResponse")
    public String vehicleGetLaneID(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_getLaneIndex", action = "Vehicle: getLaneIndex")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getLaneIndex", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLaneIndex")
    @ResponseWrapper(localName = "Vehicle_getLaneIndexResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLaneIndexResponse")
    @Action(input = "Vehicle: getLaneIndex", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getLaneIndexResponse")
    public int vehicleGetLaneIndex(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getLanePosition", action = "Vehicle: getLanePosition")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getLanePosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLanePosition")
    @ResponseWrapper(localName = "Vehicle_getLanePositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLanePositionResponse")
    @Action(input = "Vehicle: getLanePosition", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getLanePositionResponse")
    public double vehicleGetLanePosition(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getLength", action = "Vehicle: getLength")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLength")
    @ResponseWrapper(localName = "Vehicle_getLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetLengthResponse")
    @Action(input = "Vehicle: getLength", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getLengthResponse")
    public double vehicleGetLength(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getMaxSpeed", action = "Vehicle: getMaxSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetMaxSpeed")
    @ResponseWrapper(localName = "Vehicle_getMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetMaxSpeedResponse")
    @Action(input = "Vehicle: getMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getMaxSpeedResponse")
    public double vehicleGetMaxSpeed(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getMinGap", action = "Vehicle: getMinGap")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getMinGap", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetMinGap")
    @ResponseWrapper(localName = "Vehicle_getMinGapResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetMinGapResponse")
    @Action(input = "Vehicle: getMinGap", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getMinGapResponse")
    public double vehicleGetMinGap(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getNOxEmission", action = "Vehicle: Returns the NOx emission in mg for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getNOxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetNOxEmission")
    @ResponseWrapper(localName = "Vehicle_getNOxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetNOxEmissionResponse")
    @Action(input = "Vehicle: Returns the NOx emission in mg for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getNOxEmissionResponse")
    public double vehicleGetNOxEmission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getNoiseEmission", action = "Vehicle: Returns the noise emission in db for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getNoiseEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetNoiseEmission")
    @ResponseWrapper(localName = "Vehicle_getNoiseEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetNoiseEmissionResponse")
    @Action(input = "Vehicle: Returns the noise emission in db for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getNoiseEmissionResponse")
    public double vehicleGetNoiseEmission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getPMxEmission", action = "Vehicle: Returns the particular matter emission in mg for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getPMxEmission", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPMxEmission")
    @ResponseWrapper(localName = "Vehicle_getPMxEmissionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPMxEmissionResponse")
    @Action(input = "Vehicle: Returns the particular matter emission in mg for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getPMxEmissionResponse")
    public double vehicleGetPMxEmission(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns de.tudresden.ws.SumoPosition2D
     */
    @WebMethod(operationName = "Vehicle_getPosition", action = "Vehicle: Returns the position of the named vehicle within the last step [m,m].")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getPosition", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPosition")
    @ResponseWrapper(localName = "Vehicle_getPositionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetPositionResponse")
    @Action(input = "Vehicle: Returns the position of the named vehicle within the last step [m,m].", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getPositionResponse")
    public SumoPosition2D vehicleGetPosition(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getRoadID", action = "Vehicle: getRoadID")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getRoadID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRoadID")
    @ResponseWrapper(localName = "Vehicle_getRoadIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRoadIDResponse")
    @Action(input = "Vehicle: getRoadID", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getRoadIDResponse")
    public String vehicleGetRoadID(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Vehicle_getRoute", action = "Vehicle: getRoute")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getRoute", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRoute")
    @ResponseWrapper(localName = "Vehicle_getRouteResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRouteResponse")
    @Action(input = "Vehicle: getRoute", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getRouteResponse")
    public List<String> vehicleGetRoute(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getRouteID", action = "Vehicle: getRouteID")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getRouteID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRouteID")
    @ResponseWrapper(localName = "Vehicle_getRouteIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetRouteIDResponse")
    @Action(input = "Vehicle: getRouteID", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getRouteIDResponse")
    public String vehicleGetRouteID(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getShapeClass", action = "Vehicle: getShapeClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getShapeClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetShapeClass")
    @ResponseWrapper(localName = "Vehicle_getShapeClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetShapeClassResponse")
    @Action(input = "Vehicle: getShapeClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getShapeClassResponse")
    public String vehicleGetShapeClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_getSignals", action = "Vehicle: getSignals")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getSignals", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSignals")
    @ResponseWrapper(localName = "Vehicle_getSignalsResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSignalsResponse")
    @Action(input = "Vehicle: getSignals", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getSignalsResponse")
    public int vehicleGetSignals(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getSpeed", action = "Vehicle: getSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeed")
    @ResponseWrapper(localName = "Vehicle_getSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedResponse")
    @Action(input = "Vehicle: getSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getSpeedResponse")
    public double vehicleGetSpeed(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getSpeedDeviation", action = "Vehicle: getSpeedDeviation")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getSpeedDeviation", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedDeviation")
    @ResponseWrapper(localName = "Vehicle_getSpeedDeviationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedDeviationResponse")
    @Action(input = "Vehicle: getSpeedDeviation", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getSpeedDeviationResponse")
    public double vehicleGetSpeedDeviation(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getSpeedFactor", action = "Vehicle: getSpeedFactor")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getSpeedFactor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedFactor")
    @ResponseWrapper(localName = "Vehicle_getSpeedFactorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedFactorResponse")
    @Action(input = "Vehicle: getSpeedFactor", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getSpeedFactorResponse")
    public double vehicleGetSpeedFactor(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getSpeedWithoutTraCI", action = "Vehicle: getSpeedWithoutTraCI")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getSpeedWithoutTraCI", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedWithoutTraCI")
    @ResponseWrapper(localName = "Vehicle_getSpeedWithoutTraCIResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetSpeedWithoutTraCIResponse")
    @Action(input = "Vehicle: getSpeedWithoutTraCI", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getSpeedWithoutTraCIResponse")
    public double vehicleGetSpeedWithoutTraCI(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getTau", action = "Vehicle: getTau")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getTau", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetTau")
    @ResponseWrapper(localName = "Vehicle_getTauResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetTauResponse")
    @Action(input = "Vehicle: getTau", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getTauResponse")
    public double vehicleGetTau(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getTypeID", action = "Vehicle: getTypeID")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getTypeID", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetTypeID")
    @ResponseWrapper(localName = "Vehicle_getTypeIDResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetTypeIDResponse")
    @Action(input = "Vehicle: getTypeID", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getTypeIDResponse")
    public String vehicleGetTypeID(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicle_getVehicleClass", action = "Vehicle: getVehicleClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getVehicleClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetVehicleClass")
    @ResponseWrapper(localName = "Vehicle_getVehicleClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetVehicleClassResponse")
    @Action(input = "Vehicle: getVehicleClass", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getVehicleClassResponse")
    public String vehicleGetVehicleClass(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicle_getWidth", action = "Vehicle: getWidth")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_getWidth", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetWidth")
    @ResponseWrapper(localName = "Vehicle_getWidthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleGetWidthResponse")
    @Action(input = "Vehicle: getWidth", output = "http://ws.tudresden.de/Service_Impl/Vehicle_getWidthResponse")
    public double vehicleGetWidth(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_isRouteValid", action = "Vehicle: isRouteValid")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_isRouteValid", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleIsRouteValid")
    @ResponseWrapper(localName = "Vehicle_isRouteValidResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleIsRouteValidResponse")
    @Action(input = "Vehicle: isRouteValid", output = "http://ws.tudresden.de/Service_Impl/Vehicle_isRouteValidResponse")
    public int vehicleIsRouteValid(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID);

    /**
     * 
     * @param vehID
     * @param edgeList
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_setRoute", action = "Vehicle: setRoute")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_setRoute", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetRoute")
    @ResponseWrapper(localName = "Vehicle_setRouteResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetRouteResponse")
    @Action(input = "Vehicle: setRoute", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setRouteResponse")
    public int vehicleSetRoute(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "edgeList", targetNamespace = "")
        List<String> edgeList);

    /**
     * 
     * @param lcm
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_setLaneChangeMode", action = "Vehicle: setLaneChangeMode")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_setLaneChangeMode", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetLaneChangeMode")
    @ResponseWrapper(localName = "Vehicle_setLaneChangeModeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetLaneChangeModeResponse")
    @Action(input = "Vehicle: setLaneChangeMode", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setLaneChangeModeResponse")
    public int vehicleSetLaneChangeMode(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "lcm", targetNamespace = "")
        int lcm);

    /**
     * 
     * @param vehID
     * @param typeID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_setType", action = "Vehicle: setType")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_setType", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetType")
    @ResponseWrapper(localName = "Vehicle_setTypeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSetTypeResponse")
    @Action(input = "Vehicle: setType", output = "http://ws.tudresden.de/Service_Impl/Vehicle_setTypeResponse")
    public int vehicleSetType(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param duration
     * @param speed
     * @param vehID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicle_slowDown", action = "Vehicle: slowDown")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicle_slowDown", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSlowDown")
    @ResponseWrapper(localName = "Vehicle_slowDownResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicleSlowDownResponse")
    @Action(input = "Vehicle: slowDown", output = "http://ws.tudresden.de/Service_Impl/Vehicle_slowDownResponse")
    public int vehicleSlowDown(
        @WebParam(name = "vehID", targetNamespace = "")
        String vehID,
        @WebParam(name = "speed", targetNamespace = "")
        double speed,
        @WebParam(name = "duration", targetNamespace = "")
        int duration);

    /**
     * 
     * @param toGeo
     * @param edgeID
     * @param laneIndex
     * @param pos
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_convert2D", action = "Simulation: convert2D")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_convert2D", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvert2D")
    @ResponseWrapper(localName = "Simulation_convert2DResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvert2DResponse")
    @Action(input = "Simulation: convert2D", output = "http://ws.tudresden.de/Service_Impl/Simulation_convert2DResponse")
    public List<String> simulationConvert2D(
        @WebParam(name = "edgeID", targetNamespace = "")
        String edgeID,
        @WebParam(name = "pos", targetNamespace = "")
        double pos,
        @WebParam(name = "laneIndex", targetNamespace = "")
        byte laneIndex,
        @WebParam(name = "toGeo", targetNamespace = "")
        String toGeo);

    /**
     * 
     * @param fromGeo
     * @param y
     * @param x
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_convertGeo", action = "Simulation: convertGeo")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_convertGeo", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvertGeo")
    @ResponseWrapper(localName = "Simulation_convertGeoResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvertGeoResponse")
    @Action(input = "Simulation: convertGeo", output = "http://ws.tudresden.de/Service_Impl/Simulation_convertGeoResponse")
    public List<String> simulationConvertGeo(
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y,
        @WebParam(name = "fromGeo", targetNamespace = "")
        String fromGeo);

    /**
     * 
     * @param isGeo
     * @param y
     * @param x
     * @return
     *     returns de.tudresden.ws.SumoPosition2D
     */
    @WebMethod(operationName = "Simulation_convertRoad", action = "Simulation: convertRoad")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_convertRoad", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvertRoad")
    @ResponseWrapper(localName = "Simulation_convertRoadResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationConvertRoadResponse")
    @Action(input = "Simulation: convertRoad", output = "http://ws.tudresden.de/Service_Impl/Simulation_convertRoadResponse")
    public SumoPosition2D simulationConvertRoad(
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y,
        @WebParam(name = "isGeo", targetNamespace = "")
        String isGeo);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getArrivedIDList", action = "Simulation: getArrivedIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getArrivedIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetArrivedIDList")
    @ResponseWrapper(localName = "Simulation_getArrivedIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetArrivedIDListResponse")
    @Action(input = "Simulation: getArrivedIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getArrivedIDListResponse")
    public List<String> simulationGetArrivedIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getArrivedNumber", action = "Simulation: getArrivedNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getArrivedNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetArrivedNumber")
    @ResponseWrapper(localName = "Simulation_getArrivedNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetArrivedNumberResponse")
    @Action(input = "Simulation: getArrivedNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getArrivedNumberResponse")
    public int simulationGetArrivedNumber();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getCurrentTime", action = "Simulation: getCurrentTime")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getCurrentTime", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetCurrentTime")
    @ResponseWrapper(localName = "Simulation_getCurrentTimeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetCurrentTimeResponse")
    @Action(input = "Simulation: getCurrentTime", output = "http://ws.tudresden.de/Service_Impl/Simulation_getCurrentTimeResponse")
    public int simulationGetCurrentTime();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getBusStopWaiting", action = "Simulation: getBusStopWaiting")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getBusStopWaiting", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetBusStopWaiting")
    @ResponseWrapper(localName = "Simulation_getBusStopWaitingResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetBusStopWaitingResponse")
    @Action(input = "Simulation: getBusStopWaiting", output = "http://ws.tudresden.de/Service_Impl/Simulation_getBusStopWaitingResponse")
    public int simulationGetBusStopWaiting();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getDeltaT", action = "Simulation: getDeltaT")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getDeltaT", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDeltaT")
    @ResponseWrapper(localName = "Simulation_getDeltaTResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDeltaTResponse")
    @Action(input = "Simulation: getDeltaT", output = "http://ws.tudresden.de/Service_Impl/Simulation_getDeltaTResponse")
    public int simulationGetDeltaT();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getDepartedIDList", action = "Simulation: getDepartedIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getDepartedIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDepartedIDList")
    @ResponseWrapper(localName = "Simulation_getDepartedIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDepartedIDListResponse")
    @Action(input = "Simulation: getDepartedIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getDepartedIDListResponse")
    public List<String> simulationGetDepartedIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getDepartedNumber", action = "Simulation: getDepartedNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getDepartedNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDepartedNumber")
    @ResponseWrapper(localName = "Simulation_getDepartedNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDepartedNumberResponse")
    @Action(input = "Simulation: getDepartedNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getDepartedNumberResponse")
    public int simulationGetDepartedNumber();

    /**
     * 
     * @param isGeo
     * @param isDriving
     * @param y1
     * @param y2
     * @param x2
     * @param x1
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Simulation_getDistance2D", action = "Simulation: getDistance2D")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getDistance2D", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDistance2D")
    @ResponseWrapper(localName = "Simulation_getDistance2DResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDistance2DResponse")
    @Action(input = "Simulation: getDistance2D", output = "http://ws.tudresden.de/Service_Impl/Simulation_getDistance2DResponse")
    public double simulationGetDistance2D(
        @WebParam(name = "x1", targetNamespace = "")
        double x1,
        @WebParam(name = "y1", targetNamespace = "")
        double y1,
        @WebParam(name = "x2", targetNamespace = "")
        double x2,
        @WebParam(name = "y2", targetNamespace = "")
        double y2,
        @WebParam(name = "isGeo", targetNamespace = "")
        String isGeo,
        @WebParam(name = "isDriving", targetNamespace = "")
        String isDriving);

    /**
     * 
     * @param laneID
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Lane_getLinks", action = "Lane: getLinks")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getLinks", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLinks")
    @ResponseWrapper(localName = "Lane_getLinksResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetLinksResponse")
    @Action(input = "Lane: getLinks", output = "http://ws.tudresden.de/Service_Impl/Lane_getLinksResponse")
    public List<String> laneGetLinks(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns de.tudresden.ws.SumoGeometry
     */
    @WebMethod(operationName = "Lane_getShape", action = "Lane: getShape")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getShape", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetShape")
    @ResponseWrapper(localName = "Lane_getShapeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetShapeResponse")
    @Action(input = "Lane: getShape", output = "http://ws.tudresden.de/Service_Impl/Lane_getShapeResponse")
    public SumoGeometry laneGetShape(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param laneID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Lane_getWidth", action = "Lane: getWidth")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Lane_getWidth", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetWidth")
    @ResponseWrapper(localName = "Lane_getWidthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.LaneGetWidthResponse")
    @Action(input = "Lane: getWidth", output = "http://ws.tudresden.de/Service_Impl/Lane_getWidthResponse")
    public double laneGetWidth(
        @WebParam(name = "laneID", targetNamespace = "")
        String laneID);

    /**
     * 
     * @param poiType
     * @param color
     * @param layer
     * @param poiID
     * @param y
     * @param x
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Poi_add", action = "Poi: add")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_add", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiAdd")
    @ResponseWrapper(localName = "Poi_addResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiAddResponse")
    @Action(input = "Poi: add", output = "http://ws.tudresden.de/Service_Impl/Poi_addResponse")
    public int poiAdd(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID,
        @WebParam(name = "x", targetNamespace = "")
        double x,
        @WebParam(name = "y", targetNamespace = "")
        double y,
        @WebParam(name = "color", targetNamespace = "")
        SumoColor color,
        @WebParam(name = "poiType", targetNamespace = "")
        String poiType,
        @WebParam(name = "layer", targetNamespace = "")
        int layer);

    /**
     * 
     * @param poiID
     * @return
     *     returns de.tudresden.ws.SumoColor
     */
    @WebMethod(operationName = "Poi_getColor", action = "Poi: Returns the color of the given poi.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_getColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetColor")
    @ResponseWrapper(localName = "Poi_getColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetColorResponse")
    @Action(input = "Poi: Returns the color of the given poi.", output = "http://ws.tudresden.de/Service_Impl/Poi_getColorResponse")
    public SumoColor poiGetColor(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Poi_getIDList", action = "Poi: Returns a list of all pois in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetIDList")
    @ResponseWrapper(localName = "Poi_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetIDListResponse")
    @Action(input = "Poi: Returns a list of all pois in the network.", output = "http://ws.tudresden.de/Service_Impl/Poi_getIDListResponse")
    public List<String> poiGetIDList();

    /**
     * 
     * @param poiID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Poi_getType", action = "Poi: getType")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Poi_getType", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetType")
    @ResponseWrapper(localName = "Poi_getTypeResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.PoiGetTypeResponse")
    @Action(input = "Poi: getType", output = "http://ws.tudresden.de/Service_Impl/Poi_getTypeResponse")
    public String poiGetType(
        @WebParam(name = "poiID", targetNamespace = "")
        String poiID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "GUI_getIDList", action = "Gui: Returns the list of available views (open windows).")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "GUI_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetIDList")
    @ResponseWrapper(localName = "GUI_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetIDListResponse")
    @Action(input = "Gui: Returns the list of available views (open windows).", output = "http://ws.tudresden.de/Service_Impl/GUI_getIDListResponse")
    public List<String> guiGetIDList();

    /**
     * 
     * @param viewID
     * @return
     *     returns de.tudresden.ws.SumoPosition2D
     */
    @WebMethod(operationName = "GUI_getOffset", action = "Gui: Returns the x and y offset of the center of the current view.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "GUI_getOffset", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetOffset")
    @ResponseWrapper(localName = "GUI_getOffsetResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetOffsetResponse")
    @Action(input = "Gui: Returns the x and y offset of the center of the current view.", output = "http://ws.tudresden.de/Service_Impl/GUI_getOffsetResponse")
    public SumoPosition2D guiGetOffset(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID);

    /**
     * 
     * @param viewID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "GUI_getSchema", action = "Gui: Returns the name of the current coloring scheme.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "GUI_getSchema", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetSchema")
    @ResponseWrapper(localName = "GUI_getSchemaResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetSchemaResponse")
    @Action(input = "Gui: Returns the name of the current coloring scheme.", output = "http://ws.tudresden.de/Service_Impl/GUI_getSchemaResponse")
    public String guiGetSchema(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID);

    /**
     * 
     * @param viewID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "GUI_getZoom", action = "Gui: Returns the current zoom factor.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "GUI_getZoom", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetZoom")
    @ResponseWrapper(localName = "GUI_getZoomResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.GUIGetZoomResponse")
    @Action(input = "Gui: Returns the current zoom factor.", output = "http://ws.tudresden.de/Service_Impl/GUI_getZoomResponse")
    public double guiGetZoom(
        @WebParam(name = "viewID", targetNamespace = "")
        String viewID);

    /**
     * 
     * @param pos1
     * @param pos2
     * @param isDriving
     * @param edgeID1
     * @param edgeID2
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Simulation_getDistanceRoad", action = "Simulation: Returns the subscription results for the last time step.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getDistanceRoad", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDistanceRoad")
    @ResponseWrapper(localName = "Simulation_getDistanceRoadResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetDistanceRoadResponse")
    @Action(input = "Simulation: Returns the subscription results for the last time step.", output = "http://ws.tudresden.de/Service_Impl/Simulation_getDistanceRoadResponse")
    public double simulationGetDistanceRoad(
        @WebParam(name = "edgeID1", targetNamespace = "")
        String edgeID1,
        @WebParam(name = "pos1", targetNamespace = "")
        double pos1,
        @WebParam(name = "edgeID2", targetNamespace = "")
        String edgeID2,
        @WebParam(name = "pos2", targetNamespace = "")
        double pos2,
        @WebParam(name = "isDriving", targetNamespace = "")
        String isDriving);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getLoadedIDList", action = "Simulation: getLoadedIDList")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getLoadedIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetLoadedIDList")
    @ResponseWrapper(localName = "Simulation_getLoadedIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetLoadedIDListResponse")
    @Action(input = "Simulation: getLoadedIDList", output = "http://ws.tudresden.de/Service_Impl/Simulation_getLoadedIDListResponse")
    public List<String> simulationGetLoadedIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Simulation_getLoadedNumber", action = "Simulation: getLoadedNumber")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getLoadedNumber", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetLoadedNumber")
    @ResponseWrapper(localName = "Simulation_getLoadedNumberResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetLoadedNumberResponse")
    @Action(input = "Simulation: getLoadedNumber", output = "http://ws.tudresden.de/Service_Impl/Simulation_getLoadedNumberResponse")
    public int simulationGetLoadedNumber();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Simulation_getNetBoundary", action = "Simulation: getNetBoundary")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Simulation_getNetBoundary", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetNetBoundary")
    @ResponseWrapper(localName = "Simulation_getNetBoundaryResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.SimulationGetNetBoundaryResponse")
    @Action(input = "Simulation: getNetBoundary", output = "http://ws.tudresden.de/Service_Impl/Simulation_getNetBoundaryResponse")
    public List<String> simulationGetNetBoundary();

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Trafficlights_getIDList", action = "Trafficlights: Returns a list of all traffic lights in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetIDList")
    @ResponseWrapper(localName = "Trafficlights_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetIDListResponse")
    @Action(input = "Trafficlights: Returns a list of all traffic lights in the network.", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getIDListResponse")
    public List<String> trafficlightsGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Trafficlights_getIDCount", action = "Trafficlights: Returns the number of all traffic lights in the network.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetIDCount")
    @ResponseWrapper(localName = "Trafficlights_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetIDCountResponse")
    @Action(input = "Trafficlights: Returns the number of all traffic lights in the network.", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getIDCountResponse")
    public int trafficlightsGetIDCount();

    /**
     * 
     * @param tlsID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Trafficlights_getNextSwitch", action = "Trafficlights: Returns the next switch")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getNextSwitch", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetNextSwitch")
    @ResponseWrapper(localName = "Trafficlights_getNextSwitchResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetNextSwitchResponse")
    @Action(input = "Trafficlights: Returns the next switch", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getNextSwitchResponse")
    public int trafficlightsGetNextSwitch(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param tlsID
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Trafficlights_getPhase", action = "Trafficlights: getPhase")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getPhase", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetPhase")
    @ResponseWrapper(localName = "Trafficlights_getPhaseResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetPhaseResponse")
    @Action(input = "Trafficlights: getPhase", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getPhaseResponse")
    public int trafficlightsGetPhase(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param tlsID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Trafficlights_getProgram", action = "Trafficlights: getProgram")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Trafficlights_getProgram", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetProgram")
    @ResponseWrapper(localName = "Trafficlights_getProgramResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.TrafficlightsGetProgramResponse")
    @Action(input = "Trafficlights: getProgram", output = "http://ws.tudresden.de/Service_Impl/Trafficlights_getProgramResponse")
    public String trafficlightsGetProgram(
        @WebParam(name = "tlsID", targetNamespace = "")
        String tlsID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getAccel", action = "Vehicletype: getAccel")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getAccel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetAccel")
    @ResponseWrapper(localName = "Vehicletype_getAccelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetAccelResponse")
    @Action(input = "Vehicletype: getAccel", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getAccelResponse")
    public double vehicletypeGetAccel(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns de.tudresden.ws.SumoColor
     */
    @WebMethod(operationName = "Vehicletype_getColor", action = "Vehicletype: Returns the subscription results for the last time step and the given vehicle type.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getColor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetColor")
    @ResponseWrapper(localName = "Vehicletype_getColorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetColorResponse")
    @Action(input = "Vehicletype: Returns the subscription results for the last time step and the given vehicle type.", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getColorResponse")
    public SumoColor vehicletypeGetColor(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getDecel", action = "Vehicletype: getDecel")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getDecel", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetDecel")
    @ResponseWrapper(localName = "Vehicletype_getDecelResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetDecelResponse")
    @Action(input = "Vehicletype: getDecel", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getDecelResponse")
    public double vehicletypeGetDecel(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicletype_getEmissionClass", action = "Vehicletype: getEmissionClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getEmissionClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetEmissionClass")
    @ResponseWrapper(localName = "Vehicletype_getEmissionClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetEmissionClassResponse")
    @Action(input = "Vehicletype: getEmissionClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getEmissionClassResponse")
    public String vehicletypeGetEmissionClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @return
     *     returns java.util.List<java.lang.String>
     */
    @WebMethod(operationName = "Vehicletype_getIDList", action = "Vehicletype: Returns a list of all known vehicle types.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getIDList", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetIDList")
    @ResponseWrapper(localName = "Vehicletype_getIDListResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetIDListResponse")
    @Action(input = "Vehicletype: Returns a list of all known vehicle types.", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getIDListResponse")
    public List<String> vehicletypeGetIDList();

    /**
     * 
     * @return
     *     returns int
     */
    @WebMethod(operationName = "Vehicletype_getIDCount", action = "Vehicletype: Returns the number of all known vehicle types.")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getIDCount", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetIDCount")
    @ResponseWrapper(localName = "Vehicletype_getIDCountResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetIDCountResponse")
    @Action(input = "Vehicletype: Returns the number of all known vehicle types.", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getIDCountResponse")
    public int vehicletypeGetIDCount();

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getImperfection", action = "Vehicletype: getImperfection")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getImperfection", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetImperfection")
    @ResponseWrapper(localName = "Vehicletype_getImperfectionResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetImperfectionResponse")
    @Action(input = "Vehicletype: getImperfection", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getImperfectionResponse")
    public double vehicletypeGetImperfection(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getLength", action = "Vehicletype: getLength")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getLength", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetLength")
    @ResponseWrapper(localName = "Vehicletype_getLengthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetLengthResponse")
    @Action(input = "Vehicletype: getLength", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getLengthResponse")
    public double vehicletypeGetLength(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getMaxSpeed", action = "Vehicletype: getMaxSpeed")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getMaxSpeed", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetMaxSpeed")
    @ResponseWrapper(localName = "Vehicletype_getMaxSpeedResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetMaxSpeedResponse")
    @Action(input = "Vehicletype: getMaxSpeed", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getMaxSpeedResponse")
    public double vehicletypeGetMaxSpeed(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getMinGap", action = "Vehicletype: getMinGap")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getMinGap", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetMinGap")
    @ResponseWrapper(localName = "Vehicletype_getMinGapResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetMinGapResponse")
    @Action(input = "Vehicletype: getMinGap", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getMinGapResponse")
    public double vehicletypeGetMinGap(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicletype_getShapeClass", action = "Vehicletype: getShapeClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getShapeClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetShapeClass")
    @ResponseWrapper(localName = "Vehicletype_getShapeClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetShapeClassResponse")
    @Action(input = "Vehicletype: getShapeClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getShapeClassResponse")
    public String vehicletypeGetShapeClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getSpeedDeviation", action = "Vehicletype: getSpeedDeviation")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getSpeedDeviation", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetSpeedDeviation")
    @ResponseWrapper(localName = "Vehicletype_getSpeedDeviationResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetSpeedDeviationResponse")
    @Action(input = "Vehicletype: getSpeedDeviation", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getSpeedDeviationResponse")
    public double vehicletypeGetSpeedDeviation(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getSpeedFactor", action = "Vehicletype: getSpeedFactor")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getSpeedFactor", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetSpeedFactor")
    @ResponseWrapper(localName = "Vehicletype_getSpeedFactorResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetSpeedFactorResponse")
    @Action(input = "Vehicletype: getSpeedFactor", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getSpeedFactorResponse")
    public double vehicletypeGetSpeedFactor(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getTau", action = "Vehicletype: getTau")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getTau", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetTau")
    @ResponseWrapper(localName = "Vehicletype_getTauResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetTauResponse")
    @Action(input = "Vehicletype: getTau", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getTauResponse")
    public double vehicletypeGetTau(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns java.lang.String
     */
    @WebMethod(operationName = "Vehicletype_getVehicleClass", action = "Vehicletype: getVehicleClass")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getVehicleClass", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetVehicleClass")
    @ResponseWrapper(localName = "Vehicletype_getVehicleClassResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetVehicleClassResponse")
    @Action(input = "Vehicletype: getVehicleClass", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getVehicleClassResponse")
    public String vehicletypeGetVehicleClass(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

    /**
     * 
     * @param typeID
     * @return
     *     returns double
     */
    @WebMethod(operationName = "Vehicletype_getWidth", action = "Vehicletype: getWidth")
    @WebResult(targetNamespace = "")
    @RequestWrapper(localName = "Vehicletype_getWidth", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetWidth")
    @ResponseWrapper(localName = "Vehicletype_getWidthResponse", targetNamespace = "http://ws.tudresden.de/", className = "de.tudresden.ws.VehicletypeGetWidthResponse")
    @Action(input = "Vehicletype: getWidth", output = "http://ws.tudresden.de/Service_Impl/Vehicletype_getWidthResponse")
    public double vehicletypeGetWidth(
        @WebParam(name = "typeID", targetNamespace = "")
        String typeID);

}
